@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -77,13 +77,6 @@ int Channel::firstClient_ = -1;
 
 int Channel::fontPort_ = -1;
 
-//
-// Save the status of last keep
-// operation on message stores.
-//
-
-int Channel::enableKeep_ = 1;
-
 //
 // This is used for reference count.
 //
@@ -103,10 +96,11 @@ Channel::Channel(Transport *transport, StaticCompressor *compressor)
   finish_     = 0;
   closing_    = 0;
   drop_       = 0;
-  pending_    = 0;
   congestion_ = 0;
   priority_   = 0;
 
+  alert_ = 0;
+
   firstRequest_ = 1;
   firstReply_   = 1;
 
@@ -283,7 +277,7 @@ int Channel::handleEncode(EncodeBuffer &encodeBuffer, ChannelCache *channelCache
       //
 
       if (handleSplit(encodeBuffer, store, store -> lastAction,
-                          (store -> lastAction == is_added ? store -> lastAdded : 0),
+                          (store -> lastAction == IS_ADDED ? store -> lastAdded : 0),
                               opcode, buffer, size) == 1)
       {
         #ifdef MONITOR
@@ -453,7 +447,7 @@ int Channel::handleDecode(DecodeBuffer &decodeBuffer, ChannelCache *channelCache
         handleSaveSplit(store, buffer, size);
 
         handleSplit(decodeBuffer, store, store -> lastAction,
-                        (store -> lastAction == is_added ? store -> lastAdded : 0),
+                        (store -> lastAction == IS_ADDED ? store -> lastAdded : 0),
                             opcode, buffer, size);
 
         handleCleanAndNullRequest(opcode, buffer, size);
@@ -493,7 +487,7 @@ int Channel::handleDecode(DecodeBuffer &decodeBuffer, ChannelCache *channelCache
           if (split == 1)
           {
             handleSplit(decodeBuffer, store, store -> lastAction,
-                            (store -> lastAction == is_added ? store -> lastAdded : 0),
+                            (store -> lastAction == IS_ADDED ? store -> lastAdded : 0),
                                 opcode, buffer, size);
 
             handleCleanAndNullRequest(opcode, buffer, size);
@@ -526,7 +520,7 @@ int Channel::handleDecode(DecodeBuffer &decodeBuffer, ChannelCache *channelCache
     if (split == 1)
     {
       handleSplit(decodeBuffer, store, store -> lastAction,
-                      (store -> lastAction == is_added ? store -> lastAdded : 0),
+                      (store -> lastAction == IS_ADDED ? store -> lastAdded : 0),
                           opcode, buffer, size);
 
       handleCleanAndNullRequest(opcode, buffer, size);
@@ -845,33 +839,25 @@ int Channel::handleEncodeCached(EncodeBuffer &encodeBuffer, ChannelCache *channe
     // place.
     //
 
-    store -> lastAction = is_added;
+    store -> lastAction = IS_ADDED;
 
     store -> lastAdded = position;
 
     if (control -> isProtoStep7() == 1)
     {
-      encodeBuffer.encodeActionValue(is_added, store -> lastAdded,
+      encodeBuffer.encodeActionValue(IS_ADDED, store -> lastAdded,
                          store -> lastActionCache);
 
     }
     else
     {
-      encodeBuffer.encodeActionValueCompat(is_added,
+      encodeBuffer.encodeActionValueCompat(IS_ADDED,
                          store -> lastActionCacheCompat);
 
       encodeBuffer.encodePositionValueCompat(store -> lastAdded,
                          store -> lastAddedCacheCompat);
     }
 
-    //
-    // Ensure that images used at startup
-    // are retained in the repository and
-    // saved in the persistent cache.
-    //
-
-    handleStartup(store, store -> lastAdded);
-
     return 0;
   }
   else
@@ -908,18 +894,18 @@ int Channel::handleEncodeCached(EncodeBuffer &encodeBuffer, ChannelCache *channe
     // where object can be found in cache.
     //
 
-    store -> lastAction = is_hit;
+    store -> lastAction = IS_HIT;
 
     store -> lastHit = position;
 
     if (control -> isProtoStep7() == 1)
     {
-      encodeBuffer.encodeActionValue(is_hit, store -> lastHit,
+      encodeBuffer.encodeActionValue(IS_HIT, store -> lastHit,
                          store -> lastActionCache);
     }
     else
     {
-      encodeBuffer.encodeActionValueCompat(is_hit,
+      encodeBuffer.encodeActionValueCompat(IS_HIT,
                          store -> lastActionCacheCompat);
 
       encodeBuffer.encodePositionValueCompat(store -> lastHit,
@@ -934,12 +920,6 @@ int Channel::handleEncodeCached(EncodeBuffer &encodeBuffer, ChannelCache *channe
 
     store -> updateIdentity(encodeBuffer, message, cachedMessage, channelCache);
 
-    //
-    // Check if message must be kept in cache.
-    //
-
-    handleStartup(store, store -> lastHit);
-
     return 1;
   }
 }
@@ -949,7 +929,7 @@ void Channel::handleUpdateAdded(MessageStore *store, unsigned int dataSize,
 {
   #ifdef TEST
 
-  if (store -> lastAction != is_added)
+  if (store -> lastAction != IS_ADDED)
   {
     #ifdef PANIC
     *logofs << "handleUpdateAdded: " << store -> name()
@@ -1083,7 +1063,7 @@ int Channel::handleDecodeCached(DecodeBuffer &decodeBuffer, ChannelCache *channe
   // where object can be found follows.
   //
 
-  if ((T_store_action) action == is_hit)
+  if ((T_store_action) action == IS_HIT)
   {
     if (control -> isProtoStep7() == 1)
     {
@@ -1153,11 +1133,11 @@ int Channel::handleDecodeCached(DecodeBuffer &decodeBuffer, ChannelCache *channe
 
     #endif
 
-    store -> lastAction = is_hit;
+    store -> lastAction = IS_HIT;
 
     return 1;
   }
-  else if ((T_store_action) action == is_added)
+  else if ((T_store_action) action == IS_ADDED)
   {
     if (control -> isProtoStep7() == 1)
     {
@@ -1175,7 +1155,7 @@ int Channel::handleDecodeCached(DecodeBuffer &decodeBuffer, ChannelCache *channe
              << store -> lastAdded << ".\n" << logofs_flush;
     #endif
 
-    store -> lastAction = is_added;
+    store -> lastAction = IS_ADDED;
 
     return 0;
   }
@@ -1199,7 +1179,7 @@ void Channel::handleSaveAdded(MessageStore *store, int split, unsigned char *buf
 {
   #ifdef TEST
 
-  if (store -> lastAction != is_added)
+  if (store -> lastAction != IS_ADDED)
   {
     #ifdef PANIC
     *logofs << "handleSaveAdded: " << store -> name()
@@ -1297,38 +1277,6 @@ void Channel::handleSaveAdded(MessageStore *store, int split, unsigned char *buf
   #endif
 }
 
-int Channel::handleStartup(MessageStore *store, const int position)
-{
-  if (enableKeep_ == 1)
-  {
-    //
-    // We have to stop marking messages in
-    // the message store when the startup
-    // timeout is expired or when enough
-    // messages have been already marked.
-    //
-
-    if (control -> isStartup() &&
-            (control -> SessionMode == session_x ||
-                 control -> SessionMode == session_raw))
-    {
-      unsigned char opcode = store -> opcode();
-
-      if (opcode == opcodeStore_ -> putPackedImage ||
-              opcode == X_PutImage)
-      {
-        enableKeep_ = store -> keep(position);
-      }
-    }
-    else
-    {
-      enableKeep_ = 0;
-    }
-  }
-
-  return enableKeep_;
-}
-
 int Channel::handleWait(int timeout)
 {
   #ifdef TEST
@@ -1410,7 +1358,7 @@ int Channel::handleDrain(int limit, int timeout)
   #ifdef TEST
   *logofs << "handleDrain: Going to drain FD#" << fd_
           << " with a limit of " << limit << " bytes "
-          << " at " << strMsTimestamp() << ".\n"
+          << "at " << strMsTimestamp() << ".\n"
           << logofs_flush;
   #endif
 
@@ -1421,6 +1369,8 @@ int Channel::handleDrain(int limit, int timeout)
   int drained;
   int remaining;
 
+  int result;
+
   for (;;)
   {
     remaining = timeout - diffTimestamp(startTs, nowTs);
@@ -1433,7 +1383,9 @@ int Channel::handleDrain(int limit, int timeout)
               << ".\n" << logofs_flush;
       #endif
 
-      return 0;
+      result = 0;
+
+      goto ChannelDrainEnd;
     }
 
     #ifdef TEST
@@ -1448,13 +1400,16 @@ int Channel::handleDrain(int limit, int timeout)
     {
       #ifdef TEST
       *logofs << "handleDrain: Transport for FD#" << fd_
-              << " drained down to " << transport_ -> length()
-              << " bytes.\n" << logofs_flush;
+              << " drained to " << transport_ -> length()
+              << " bytes at " << strMsTimestamp() << ".\n"
+              << logofs_flush;
       #endif
 
-      return 1;
+      result = 1;
+
+      goto ChannelDrainEnd;
     }
-    if (drained == 0 && transport_ -> readable() > 0)
+    else if (drained == 0 && transport_ -> readable() > 0)
     {
       #ifdef TEST
       *logofs << "handleDrain: WARNING! Encoding more data "
@@ -1464,12 +1419,12 @@ int Channel::handleDrain(int limit, int timeout)
 
       if (proxy -> handleAsyncRead(fd_) < 0)
       {
-        return -1;
+        goto ChannelDrainError;
       }
     }
     else if (drained == -1)
     {
-      return -1;
+      goto ChannelDrainError;
     }
 
     nowTs = getNewTimestamp();
@@ -1487,16 +1442,117 @@ int Channel::handleDrain(int limit, int timeout)
       cerr << "Warning" << ": Can't write to connection on FD#"
            << fd_ << " since " << seconds << " seconds.\n";
 
-      if (control -> ProxyMode == proxy_client)
+      if (alert_ == 0)
       {
-        HandleAlert(CLOSE_DEAD_X_CONNECTION_CLIENT_ALERT, 1);
-      }
-      else
-      {
-        HandleAlert(CLOSE_DEAD_X_CONNECTION_SERVER_ALERT, 1);
+        if (control -> ProxyMode == proxy_client)
+        {
+          alert_ = CLOSE_DEAD_X_CONNECTION_CLIENT_ALERT;
+        }
+        else
+        {
+          alert_ = CLOSE_DEAD_X_CONNECTION_SERVER_ALERT;
+        }
+
+        HandleAlert(alert_, 1);
       }
     }
   }
+
+ChannelDrainEnd:
+
+  //
+  // Maybe we drained the channel and are
+  // now out of the congestion state.
+  //
+
+  handleCongestion();
+
+  return result;
+
+ChannelDrainError:
+
+  finish_ = 1;
+
+  return -1;
+}
+
+int Channel::handleCongestion()
+{
+  //
+  // Send a begin congestion control code
+  // if the local end of the channel does
+  // not consume its data.
+  //
+
+  if (isCongested() == 1)
+  {
+    if (congestion_ == 0)
+    {
+      #if defined(TEST) || defined(INFO)
+      *logofs << "handleCongestion: Sending congestion for FD#"
+              << fd_ << " with length " << transport_ -> length()
+              << " at " << strMsTimestamp() << ".\n"
+              << logofs_flush;
+      #endif
+
+      congestion_ = 1;
+
+      //
+      // Use the callback to send the control
+      // code immediately.
+      //
+
+      if (proxy -> handleAsyncCongestion(fd_) < 0)
+      {
+        finish_ = 1;
+
+        return -1;
+      }
+    }
+  }
+  else
+  {
+    //
+    // If the channel was in congestion state
+    // send an end congestion control code.
+    //
+
+    if (congestion_ == 1)
+    {
+      #if defined(TEST) || defined(INFO)
+      *logofs << "handleCongestion: Sending decongestion for FD#"
+              << fd_ << " with length " << transport_ -> length()
+              << " at " << strMsTimestamp() << ".\n"
+              << logofs_flush;
+      #endif
+
+      congestion_ = 0;
+
+      if (proxy -> handleAsyncDecongestion(fd_) < 0)
+      {
+        finish_ = 1;
+
+        return -1;
+      }
+    }
+
+    //
+    // Remove the "channel unresponsive"
+    // dialog.
+    //
+
+    if (alert_ != 0)
+    {
+      #if defined(TEST) || defined(INFO)
+      *logofs << "handleCongestion: Displacing the dialog "
+              << "for FD#" << fd_ << ".\n" << logofs_flush;
+      #endif
+
+      HandleAlert(DISPLACE_MESSAGE_ALERT, 1);
+    }
+  }
+
+  return 1;
 }
 
 int Channel::handleFlush(T_flush type, int bufferLength, int scratchLength)
@@ -1504,7 +1560,7 @@ int Channel::handleFlush(T_flush type, int bufferLength, int scratchLength)
   if (finish_ == 1)
   {
     #ifdef TEST
-    *logofs << "handleFlush: No data flushed for "
+    *logofs << "handleFlush: Not flushing data for "
             << "finishing channel for FD#" << fd_
             << ".\n" << logofs_flush;
     #endif
@@ -1515,20 +1571,32 @@ int Channel::handleFlush(T_flush type, int bufferLength, int scratchLength)
   }
 
   #ifdef TEST
-  *logofs << "handleFlush: Going to flush " << bufferLength
-          << " + " << scratchLength << " bytes of data "
-          << "to FD#" << fd_ << ".\n" << logofs_flush;
+  *logofs << "handleFlush: Flushing " << bufferLength
+          << " + " << scratchLength << " bytes "
+          << "to FD#" << fd_ << ".\n"
+          << logofs_flush;
   #endif
 
   //
-  // First write data from normal buffer followed by
-  // data from scratch buffer then cleanup everything.
-  // Best performances are with small buffers (between
-  // 1 and 4 KBytes) with TCP_NODELAY set on socket.
+  // Check if the channel has data available.
+  // Recent Linux kernels are very picky.
+  // They require that we read often or they
+  // assume that the process is non-interact-
+  // ive.
   //
 
   int result = 0;
 
+  if (handleAsyncEvents() < 0)
+  {
+    goto ChannelFlushError;
+  }
+
+  //
+  // Write the data in the main buffer first,
+  // followed by the data in the scratch buffer.
+  //
+
   if (bufferLength > 0)
   {
     result = transport_ -> write(write_immediate,
@@ -1550,10 +1618,6 @@ int Channel::handleFlush(T_flush type, int bufferLength, int scratchLength)
     writeBuffer_.partialReset();
   }
 
-  int limit = getLimit();
-
-  int length = transport_ -> length();
-
   //
   // If we failed to write to the X connection then
   // set the finish flag. The caller should continue
@@ -1569,49 +1633,44 @@ int Channel::handleFlush(T_flush type, int bufferLength, int scratchLength)
   }
 
   //
-  // Verify that the channel has not exceeded the
-  // limits, otherwise try to write some of the
-  // data before returning control to the caller.
+  // Reset transport buffers.
   //
 
-  if (isReliable() == 1)
-  {
-    if (length > limit)
-    {
-      if (handleDrain(limit, control -> ChannelTimeout / 2) < 0)
-      {
-        goto ChannelFlushError;
-      }
-    }
+  transport_ -> partialReset();
 
-    length = transport_ -> length();
+  //
+  // Check if the X server has generated
+  // any event in response to our data.
+  //
+
+  if (handleAsyncEvents() < 0)
+  {
+    goto ChannelFlushError;
   }
 
-  if (length > limit)
-  {
-    if (congestion_ == 0)
-    {
-      #ifdef WARNING
-      *logofs << "handleFlush: WARNING! Sending congestion for FD#"
-              << fd_ << " with length " << length << ".\n"
-              << logofs_flush;
-      #endif
+  //
+  // Check if the channel has entered in
+  // congestion state and, in this case,
+  // send an immediate congestion control
+  // code to the remote.
+  //
 
-      congestion_ = 1;
+  handleCongestion();
 
-      //
-      // Use the callback to send the control
-      // code immediately.
-      //
+  //
+  // We could optionally drain the output
+  // buffer if this is X11 channel.
+  //
+  // if (isCongested() == 1 && isReliable() == 1)
+  // {
+  //   if (handleDrain(0, control -> ChannelTimeout) < 0)
+  //   {
+  //     goto ChannelFlushError;
+  //   }
+  // }
+  //
 
-      if (proxy -> handleAsyncCongestion(fd_) < 0)
-      {
-        goto ChannelFlushError;
-      }
-    }
-  }
-
-  return result;
+  return 1;
 
 ChannelFlushError:
 
@@ -1620,6 +1679,78 @@ ChannelFlushError:
   return -1;
 }
 
+int Channel::handleFlush()
+{
+  #ifdef TEST
+  *logofs << "handleFlush: Flushing "
+          << transport_ -> length() << " bytes to FD#"
+          << fd_ << " with descriptor writable.\n"
+          << logofs_flush;
+  #endif
+
+  //
+  // Check if there is anything to read
+  // before anf after having written to
+  // the socket.
+  //
+
+  if (handleAsyncEvents() < 0)
+  {
+    goto ChannelFlushError;
+  }
+
+  if (transport_ -> flush() < 0)
+  {
+    #ifdef TEST
+    *logofs << "handleFlush: Failure detected "
+            << "flushing data to FD#" << fd_
+            << ".\n" << logofs_flush;
+    #endif
+
+    goto ChannelFlushError;
+  }
+
+  if (handleAsyncEvents() < 0)
+  {
+    goto ChannelFlushError;
+  }
+
+  //
+  // Reset channel's transport buffers.
+  //
+
+  transport_ -> partialReset();
+
+  //
+  // Check if the channel went out of the
+  // congestion state.
+  //
+
+  handleCongestion();
+
+  return 1;
+
+ChannelFlushError:
+
+  finish_ = 1;
+
+  return -1;
+}
+
+void Channel::handleResetAlert()
+{
+  if (alert_ != 0)
+  {
+    #ifdef TEST
+    *logofs << "handleResetAlert: The channel alert '"
+            << alert_ << "' was displaced.\n"
+            << logofs_flush;
+    #endif
+
+    alert_ = 0;
+  }
+}
+
 int Channel::handleCompress(EncodeBuffer &encodeBuffer, const unsigned char opcode,
                                 const unsigned int offset, const unsigned char *buffer,
                                     const unsigned int size, unsigned char *&compressedData,
@@ -1946,8 +2077,6 @@ int Channel::setReferences()
 
   fontPort_ = -1;
 
-  enableKeep_ = 1;
-
   #ifdef REFERENCES
 
   references_ = 0;
