@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -58,7 +58,7 @@ int ClearAreaStore::parseIdentity(Message *message, const unsigned char *buffer,
   *logofs << name() << ": Parsed Identity for message at " << this << ".\n" << logofs_flush;
   #endif
 
-  return true;
+  return 1;
 }
 
 int ClearAreaStore::unparseIdentity(const Message *message, unsigned char *buffer,
@@ -83,7 +83,7 @@ int ClearAreaStore::unparseIdentity(const Message *message, unsigned char *buffe
   *logofs << name() << ": Unparsed identity for message at " << this << ".\n" << logofs_flush;
   #endif
 
-  return true;
+  return 1;
 }
 
 void ClearAreaStore::dumpIdentity(const Message *message) const
