@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -109,6 +109,9 @@ ClientCache::ClientCache() :
 
   renderTextCompressor(textCache, CLIENT_TEXT_CACHE_SIZE),
 
+  renderGlyphXCache(16), renderGlyphYCache(16),
+  renderGlyphX(0), renderGlyphY(0),
+
   renderLastCompositeGlyphsData(0),
 
   setCacheParametersCache(8),
