@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -34,13 +34,6 @@
 #undef  TEST
 #undef  DEBUG
 
-//
-// Log operations related to handling
-// the synchronization requests.
-//
-
-#undef  SYNC
-
 //
 // If defined, the client channel will
 // have the chance of suppressing more
@@ -69,7 +62,8 @@ class ClientChannel : public Channel
 
   virtual ~ClientChannel();
 
-  virtual int handleRead(EncodeBuffer &encodeBuffer);
+  virtual int handleRead(EncodeBuffer &encodeBuffer, const unsigned char *message,
+                             unsigned int length);
 
   virtual int handleWrite(const unsigned char *message, unsigned int length);
 
@@ -109,7 +103,10 @@ class ClientChannel : public Channel
 
   virtual int handleFinish();
 
-  virtual int handleNotify(T_notification_type type);
+  virtual int handleAsyncEvents()
+  {
+    return 0;
+  }
 
   virtual int needSplit() const
   {
@@ -129,40 +126,9 @@ class ClientChannel : public Channel
     return 0;
   }
 
-  virtual int needLimit() const
-  {
-    return (transport_ -> length() >=
-                control -> TransportXBufferLimit);
-  }
-
-  virtual int getLimit() const
-  {
-    return (control -> TransportXBufferLimit);
-  }
-
   virtual T_channel_type getType() const
   {
-    return channel_x;
-  }
-
-  //
-  // Used to implement synchronization
-  // between proxies.
-  //
-
-  virtual int getClientSequence() const
-  {
-    return clientSequence_;
-  }
-
-  virtual int getServerSequence() const
-  {
-    return serverSequence_;
-  }
-
-  virtual int getRequest() const
-  {
-    return lastRequest_;
+    return channel_x11;
   }
 
   int setBigEndian(int flag);
@@ -411,13 +377,6 @@ class ClientChannel : public Channel
 
   void handleDecodeCharInfo(DecodeBuffer &, unsigned char *);
 
-  //
-  // Check if it's time to give up reading
-  // from the channel.
-  //
-
-  int handleProxyEvents();
-
   //
   // Own read buffer. It is able to identify
   // full messages read from the X descriptor.
