@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -88,7 +88,7 @@ int ClientProxy::handleNewConnection(T_channel_type type, int clientFd)
 {
   switch (type)
   {
-    case channel_x:
+    case channel_x11:
     {
       return handleNewXConnection(clientFd);
     }
@@ -194,6 +194,8 @@ int ClientProxy::handleNewAgentConnection(Agent *agent)
 
   transports_[channelId] = agent -> getTransport();
 
+  agent_ = channelId;
+
   return handleNewXConnection(clientFd);
 }
 
@@ -308,17 +310,6 @@ int ClientProxy::handleNewXConnection(int clientFd)
 
   channels_[channelId] -> handleConfiguration();
 
-  //
-  // Check whether this is the first channel
-  // and assume that it is our controlling
-  // connection.
-  //
-
-  if (agentChannel_ == -1)
-  {
-    agentChannel_ = channelId;
-  }
-
   return 1;
 }
 
@@ -338,7 +329,7 @@ int ClientProxy::handleNewXConnectionFromProxy(int channelId)
 
 int ClientProxy::handleLoad(T_load_type type)
 {
-  int channelCount = getChannels(channel_x);
+  int channelCount = getChannels(channel_x11);
 
   if ((channelCount == 0 && type == load_if_first) ||
           (channelCount > 0 && type == load_if_any))
@@ -414,7 +405,7 @@ int ClientProxy::handleSave()
   // then save content of message stores.
   //
 
-  int channelCount = getChannels(channel_x);
+  int channelCount = getChannels(channel_x11);
 
   if (channelCount == 0)
   {
@@ -455,6 +446,27 @@ int ClientProxy::handleSave()
   return 1;
 }
 
+int ClientProxy::handleAsyncEvents()
+{
+  if (canRead() == 1)
+  {
+    #if defined(TEST) || defined(INFO)
+    *logofs << "Proxy: WARNING! Reading while writing "
+            << "with data available on the proxy link.\n"
+            << logofs_flush;
+    #endif
+
+    if (handleRead() < 0)
+    {
+      return -1;
+    }
+
+    return 1;
+  }
+
+  return 0;
+}
+
 int ClientProxy::handleLoadFromProxy()
 {
   #ifdef PANIC
