@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -24,6 +24,25 @@
 #undef  TEST
 #undef  DEBUG
 
+unsigned int ClientReadBuffer::suggestedLength(unsigned int pendingLength)
+{
+  //
+  // Even if the pending data is not
+  // enough to make a complete message,
+  // resize the buffer to accomodate
+  // it all.
+  //
+
+  unsigned int readLength = pendingLength;
+
+  if (pendingLength < remaining_)
+  {
+    readLength = remaining_;
+  }
+
+  return readLength;
+}  
+
 int ClientReadBuffer::locateMessage(const unsigned char *start,
                                         const unsigned char *end,
                                             unsigned int &controlLength,
@@ -35,8 +54,7 @@ int ClientReadBuffer::locateMessage(const unsigned char *start,
   #ifdef TEST
   *logofs << "ClientReadBuffer: Locating message for FD#"
           << transport_ -> fd() << " with " << size
-          << " bytes and remaining " << remaining_
-          << ".\n" << logofs_flush;
+          << " bytes.\n" << logofs_flush;
   #endif
 
   if (firstMessage_)
