@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -277,25 +277,13 @@ int DecodeBuffer::decodeCachedValue(unsigned int &value, unsigned int numBits,
 
   if (index == 2)
   {
-    unsigned int sameDiff;
-
-    decodeBoolValue(sameDiff);
-
-    if (sameDiff)
-    {
-      value = cache.getLastDiff(PARTIAL_INT_MASK[numBits]);
-
-      cache.insert(value, PARTIAL_INT_MASK[numBits]);
-
-      return 1;
-    }
-    else
+    if (control -> isProtoStep8() == 1)
     {
       blockSize = cache.getBlockSize(blockSize);
 
       if (decodeValue(value, numBits, blockSize, endOkay))
       {
-        cache.insert(value, PARTIAL_INT_MASK[numBits]);
+        cache.insert(value, IntMask[numBits]);
 
         return 1;
       }
@@ -310,8 +298,42 @@ int DecodeBuffer::decodeCachedValue(unsigned int &value, unsigned int numBits,
 
       HandleAbort();
     }
+    else
+    {
+      unsigned int sameDiff;
 
-    return 0;
+      decodeBoolValue(sameDiff);
+
+      if (sameDiff)
+      {
+        value = cache.getLastDiff(IntMask[numBits]);
+
+        cache.insert(value, IntMask[numBits]);
+
+        return 1;
+      }
+      else
+      {
+        blockSize = cache.getBlockSize(blockSize);
+
+        if (decodeValue(value, numBits, blockSize, endOkay))
+        {
+          cache.insert(value, IntMask[numBits]);
+
+          return 1;
+        }
+
+        #ifdef PANIC
+        *logofs << "DecodeBuffer: PANIC! Assertion failed. Error [H] "
+                << "in decodeCacheValue() with no value found.\n"
+                << logofs_flush;
+        #endif
+
+        cerr << "Error" << ": Failure decoding data in context [H].\n";
+
+        HandleAbort();
+      }
+    }
   }
   else
   {
