@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -111,8 +111,7 @@ void EncodeBuffer::encodeValue(unsigned int value, unsigned int numBits,
           << " bytes in buffer.\n" << logofs_flush;
   #endif
 
-  unsigned int clearMask = ~0;
-  value &= clearMask >> (sizeof(unsigned int) * 8 - numBits);
+  value &= IntMask[numBits];
 
   unsigned int srcMask = 0x1;
   unsigned int bitsWritten = 0;
@@ -208,8 +207,7 @@ void EncodeBuffer::encodeCachedValue(unsigned int value, unsigned int numBits,
           << " bytes in buffer.\n" << logofs_flush;
   #endif
 
-  unsigned int clearMask = ~0;
-  value &= clearMask >> (sizeof(unsigned int) * 8 - numBits);
+  value &= IntMask[numBits];
 
   if (end_ - nextDest_ < 8)
   {
@@ -227,7 +225,7 @@ void EncodeBuffer::encodeCachedValue(unsigned int value, unsigned int numBits,
 
   #endif
 
-  if (cache.lookup(value, index, PARTIAL_INT_MASK[numBits], sameDiff))
+  if (cache.lookup(value, index, IntMask[numBits], sameDiff))
   {
     if (index > 1)
       index++;
@@ -258,34 +256,52 @@ void EncodeBuffer::encodeCachedValue(unsigned int value, unsigned int numBits,
     *nextDest_ |= (1 << destShift_);
     ADVANCE_DEST;
 
-    if (sameDiff)
+    //
+    // The attempt is very seldom successful.
+    // Avoid to encode the additional bool.
+    //
+
+    if (control -> isProtoStep8() == 1)
     {
       #ifdef DUMP
-      *logofs << "EncodeBuffer: Matched difference with block size "
-              << cache.getBlockSize(blockSize) << ".\n"
-              << logofs_flush;
+      *logofs << "EncodeBuffer: Encoded missed int using "
+              << diffBits() << " bits out of " << numBits
+              << ".\n" << logofs_flush;
       #endif
 
-      encodeBoolValue(1);
-    }
-    else
-    {
-      #ifdef DUMP
-      *logofs << "EncodeBuffer: Missed difference with block size "
-              << cache.getBlockSize(blockSize) << ".\n"
-              << logofs_flush;
-      #endif
-
-      encodeBoolValue(0);
-
       encodeValue(value, numBits, blockSize);
     }
+    else
+    {
+      if (sameDiff)
+      {
+        #ifdef DUMP
+        *logofs << "EncodeBuffer: Matched difference with block size "
+                << cache.getBlockSize(blockSize) << ".\n"
+                << logofs_flush;
+        #endif
 
-    #ifdef DUMP
-    *logofs << "EncodeBuffer: Encoded missed int using "
-            << diffBits() << " bits out of " << numBits
-            << ".\n" << logofs_flush;
-    #endif
+        encodeBoolValue(1);
+      }
+      else
+      {
+        #ifdef DUMP
+        *logofs << "EncodeBuffer: Missed difference with block size "
+                << cache.getBlockSize(blockSize) << ".\n"
+                << logofs_flush;
+        #endif
+
+        encodeBoolValue(0);
+
+        encodeValue(value, numBits, blockSize);
+      }
+
+      #ifdef DUMP
+      *logofs << "EncodeBuffer: Encoded missed int using "
+              << diffBits() << " bits out of " << numBits
+              << ".\n" << logofs_flush;
+      #endif
+    }
   }
 }
 
@@ -299,8 +315,7 @@ void EncodeBuffer::encodeCachedValue(unsigned char value, unsigned int numBits,
           << " bytes in buffer.\n" << logofs_flush;
   #endif
 
-  unsigned int clearMask = ~0;
-  value &= clearMask >> (sizeof(unsigned int) * 8 - numBits);
+  value &= IntMask[numBits];
 
   if (end_ - nextDest_ < 8)
   {
@@ -602,7 +617,7 @@ void EncodeBuffer::encodeNewXidValue(unsigned int value, unsigned int &lastId,
 
   cache.base_[cache.slot_] -> push(t, 0x1fffffff);
 
-  freeCache.push(value, PARTIAL_INT_MASK[29]);
+  freeCache.push(value, IntMask[29]);
 }
 
 void EncodeBuffer::encodeXidValue(unsigned int value, XidCache &cache)
