@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -51,11 +51,23 @@ int FillPolyStore::parseIdentity(Message *message, const unsigned char *buffer,
   fillPoly -> shape = *(buffer + 12);
   fillPoly -> mode  = *(buffer + 13);
 
+  if (control -> isProtoStep8() == 1 &&
+          size >= (unsigned int) dataOffset)
+  {
+    fillPoly -> x_origin = GetUINT(buffer + 16, bigEndian);
+    fillPoly -> y_origin = GetUINT(buffer + 18, bigEndian);
+  }
+  else
+  {
+    fillPoly -> x_origin = 0;
+    fillPoly -> y_origin = 0;
+  }
+
   #ifdef DEBUG
   *logofs << name() << ": Parsed Identity for message at " << this << ".\n" << logofs_flush;
   #endif
 
-  return true;
+  return 1;
 }
 
 int FillPolyStore::unparseIdentity(const Message *message, unsigned char *buffer,
@@ -73,11 +85,18 @@ int FillPolyStore::unparseIdentity(const Message *message, unsigned char *buffer
   *(buffer + 12) = fillPoly -> shape;
   *(buffer + 13) = fillPoly -> mode;
 
+  if (control -> isProtoStep8() == 1 &&
+          size >= (unsigned int) dataOffset)
+  {
+    PutUINT(fillPoly -> x_origin, buffer + 16, bigEndian);
+    PutUINT(fillPoly -> y_origin, buffer + 18, bigEndian);
+  }
+
   #ifdef DEBUG
   *logofs << name() << ": Unparsed identity for message at " << this << ".\n" << logofs_flush;
   #endif
 
-  return true;
+  return 1;
 }
 
 void FillPolyStore::dumpIdentity(const Message *message) const
@@ -89,7 +108,9 @@ void FillPolyStore::dumpIdentity(const Message *message) const
   *logofs << name() << ": Identity drawable " << fillPoly -> drawable
                     << ", gcontext " << fillPoly -> gcontext << ", shape "
                     << fillPoly -> shape << ", mode " << fillPoly -> mode
-                    << fillPoly -> size_ << ".\n" << logofs_flush;
+                    << fillPoly -> size_ << ", x_origin " << fillPoly -> x_origin
+                    << ", y_origin " << fillPoly -> y_origin << ".\n"
+                    << logofs_flush;
   #endif
 }
 
@@ -129,6 +150,30 @@ void FillPolyStore::updateIdentity(EncodeBuffer &encodeBuffer, const Message *me
   encodeBuffer.encodeXidValue(fillPoly -> gcontext, clientCache -> gcCache);
 
   cachedFillPoly -> gcontext = fillPoly -> gcontext;
+
+  if (control -> isProtoStep8() == 1 &&
+          fillPoly -> size_ >= dataOffset)
+  {
+    #ifdef TEST
+    *logofs << name() << ": Encoding value " << fillPoly -> x_origin
+        << " as x_origin field.\n" << logofs_flush;
+    #endif
+
+    encodeBuffer.encodeCachedValue(fillPoly -> x_origin, 16,
+                 *clientCache -> fillPolyXAbsCache[0], 8);
+
+    cachedFillPoly -> x_origin = fillPoly -> x_origin;
+
+    #ifdef TEST
+    *logofs << name() << ": Encoding value " << fillPoly -> y_origin
+            << " as y_origin field.\n" << logofs_flush;
+    #endif
+
+    encodeBuffer.encodeCachedValue(fillPoly -> y_origin, 16,
+                 *clientCache -> fillPolyYAbsCache[0], 8);
+
+    cachedFillPoly -> y_origin = fillPoly -> y_origin;
+  }
 }
 
 void FillPolyStore::updateIdentity(DecodeBuffer &decodeBuffer, const Message *message,
@@ -138,25 +183,45 @@ void FillPolyStore::updateIdentity(DecodeBuffer &decodeBuffer, const Message *me
 
   ClientCache *clientCache = (ClientCache *) channelCache;
 
-  unsigned int value;
+  decodeBuffer.decodeXidValue(fillPoly -> drawable, clientCache -> drawableCache);
 
-  decodeBuffer.decodeXidValue(value, clientCache -> drawableCache);
-
-  fillPoly -> drawable = value;
-
-  #ifdef DEBUG
+  #ifdef TEST
   *logofs << name() << ": Decoded value " << fillPoly -> drawable
           << " as drawable field.\n" << logofs_flush;
   #endif
 
-  decodeBuffer.decodeXidValue(value, clientCache -> gcCache);
+  decodeBuffer.decodeXidValue(fillPoly -> gcontext, clientCache -> gcCache);
 
-  fillPoly -> gcontext = value;
-
-  #ifdef DEBUG
+  #ifdef TEST
   *logofs << name() << ": Decoded value " << fillPoly -> gcontext
           << " as gcontext field.\n" << logofs_flush;
   #endif
+
+  if (control -> isProtoStep8() == 1 &&
+          fillPoly -> size_ >= dataOffset)
+  {
+    unsigned int value;
+
+    decodeBuffer.decodeCachedValue(value, 16,
+                 *clientCache -> fillPolyXAbsCache[0], 8);
+
+    fillPoly -> x_origin = value;
+
+    #ifdef TEST
+    *logofs << name() << ": Decoded value " << fillPoly -> x_origin
+            << " as x_origin field.\n" << logofs_flush;
+    #endif
+
+    decodeBuffer.decodeCachedValue(value, 16,
+                 *clientCache -> fillPolyYAbsCache[0], 8);
+
+    fillPoly -> y_origin = value;
+
+    #ifdef TEST
+    *logofs << name() << ": Decoded value " << fillPoly -> y_origin
+            << " as y_origin field.\n" << logofs_flush;
+    #endif
+  }
 }
 
 
