@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -89,16 +89,19 @@ GenericChannel::~GenericChannel()
 // Beginning of handleRead().
 //
 
-int GenericChannel::handleRead(EncodeBuffer &encodeBuffer)
+int GenericChannel::handleRead(EncodeBuffer &encodeBuffer, const unsigned char *message,
+                                   unsigned int length)
 {
-  #ifdef DEBUG
+  #ifdef TEST
   *logofs << "handleRead: Called for FD#" << fd_
-          << ".\n" << logofs_flush;
+          << " with " << encodeBuffer.getLength()
+          << " bytes already encoded.\n"
+          << logofs_flush;
   #endif
 
   //
-  // Pointer to located message and its
-  // size in bytes.
+  // Pointer to located message and
+  // its size in bytes.
   //
 
   const unsigned char *inputMessage;
@@ -112,210 +115,136 @@ int GenericChannel::handleRead(EncodeBuffer &encodeBuffer)
 
   unsigned char inputOpcode = X_NXInternalGenericData;
 
-  //
-  // How many times we read from the
-  // the socket and total bytes read.
-  //
-
-  int bytes = 0;
-  int reads = 0;
-
-  for (;;)
-  {
-    #if defined(TEST) || defined(INFO)
-    *logofs << "handleRead: Trying to read with " << reads
-            << " reads and " << bytes << " bytes for FD#"
-            << fd_ << " at " << strMsTimestamp() << ".\n"
-            << logofs_flush;
-    #endif
-
-    #if defined(TEST) || defined(INFO)
-
-    if (pending_ != 0)
-    {
-      *logofs << "handleRead: PANIC! Pending is set for FD#"
-              << fd_ << ".\n" << logofs_flush;
-
-      HandleCleanup();
-    }
-
-    #endif
-
-    int result = readBuffer_.readMessage();
-
-    #ifdef DEBUG
-    *logofs << "handleRead: Read result on FD#" << fd_
-            << " is " << result << " with pending "
-            << pending_ << ".\n" << logofs_flush;
-    #endif
-
-    if (result < 0)
-    {
-      if (bytes == 0)
-      {
-        return -1;
-      }
-      else
-      {
-        break;
-      }
-    }
-    else if (result == 0 && pending_ == 0)
-    {
-      #if defined(TEST) || defined(INFO)
-
-      if (reads == 0)
-      {
-        *logofs << "handleRead: PANIC! No data read from FD#"
-                << fd_ << " while encoding messages.\n"
-                << logofs_flush;
-
-        HandleCleanup();
-      }
-
-      #endif
-
-      break;
-    }
-
-    reads++;
-
-    #if defined(TEST) || defined(INFO) || defined(FLUSH)
-    *logofs << "handleRead: Encoding messages for FD#" << fd_
-            << " with " << readBuffer_.getLength() << " bytes "
-            << "in the buffer.\n" << logofs_flush;
-    #endif
-
-    //
-    // Divide the available data in multiple
-    // messages and encode them one by one.
-    //
-
-    while ((inputMessage = readBuffer_.getMessage(inputLength)) != NULL)
-    {
-      bytes += inputLength;
-
-      if (proxy -> handleAsyncSwitch(fd_) < 0)
-      {
-        return -1;
-      }
-
-      encodeBuffer.encodeValue(inputLength, 32, 14);
-
-      if (isCompressed() == 1)
-      {
-        unsigned int compressedDataSize = 0;
-        unsigned char *compressedData   = NULL;
-
-        if (handleCompress(encodeBuffer, inputOpcode, 0,
-                               inputMessage, inputLength, compressedData,
-                                   compressedDataSize) < 0)
-        {
-          return -1;
-        }
-      }
-      else
-      {
-        encodeBuffer.encodeMemory(inputMessage, inputLength);
-      }
-
-      int bits = encodeBuffer.diffBits();
-
-      #if defined(TEST) || defined(OPCODES)
-      *logofs << "handleRead: Handled generic data for FD#" << fd_
-              << ". " << inputLength << " bytes in, " << bits << " bits ("
-              << ((float) bits) / 8 << " bytes) out.\n" << logofs_flush;
-      #endif
-
-      addProtocolBits(inputLength << 3, bits);
-
-      if (isPrioritized() == 1)
-      {
-        priority_++;
-      }
-
-    } // End of while ((inputMessage = readBuffer_.getMessage(inputLength)) != NULL) ...
-
-    //
-    // All data has been read from the read buffer.
-    // We'll need to mark the end of the encode
-    // buffer just before sending the frame. This
-    // allows us to accomodate multiple reads in
-    // a single frame.
-    //
-
-    pending_ = 0;
-
-    //
-    // Check if we read the scheduled amount for
-    // this channel.
-    //
-
-    if (bytes >= control -> GenericMaximumReadSize)
-    {
-      if (isInteractive() == 0)
-      {
-        #ifdef TEST
-        *logofs << "handleRead: Giving up because of limit of "
-                << control -> GenericMaximumReadSize << " bytes "
-                << "read for FD#" << fd_ << ".\n"
-                << logofs_flush;
-        #endif
-
-        break;
-      }
-
-      //#ifdef TEST
-      *logofs << "handleRead: Not applying limits to descriptor "
-              << "FD#" << fd_ << " with type '" << getType()
-              << "'.\n" << logofs_flush;
-      //#endif
-    }
-
-    if (handleProxyEvents() != 0)
-    {
-      break;
-    }
-
-  } // End of for (;;) ...
-
   #if defined(TEST) || defined(INFO)
+  *logofs << "handleRead: Trying to read from FD#"
+          << fd_ << " at " << strMsTimestamp() << ".\n"
+          << logofs_flush;
+  #endif
 
-  if (transport_ -> pending() != 0 || readBuffer_.checkMessage() != 0)
+  int result = readBuffer_.readMessage();
+
+  #ifdef DEBUG
+  *logofs << "handleRead: Read result on FD#" << fd_
+          << " is " << result << ".\n"
+          << logofs_flush;
+  #endif
+
+  if (result < 0)
   {
-    *logofs << "handleRead: PANIC! Buffer for X descriptor FD#"
-            << fd_ << " has " << transport_ -> pending()
-            << " bytes to read and pending flag "
-            << pending_ << ".\n" << logofs_flush;
+    //
+    // Let the proxy close the channel.
+    //
+
+    return -1;
+  }
+  else if (result == 0)
+  {
+    #if defined(TEST) || defined(INFO)
+
+    *logofs << "handleRead: PANIC! No data read from FD#"
+            << fd_ << " while encoding messages.\n"
+            << logofs_flush;
 
     HandleCleanup();
+
+    #endif
+
+    return 0;
   }
 
+  #if defined(TEST) || defined(INFO) || defined(FLUSH)
+  *logofs << "handleRead: Encoding messages for FD#" << fd_
+          << " with " << readBuffer_.getLength() << " bytes "
+          << "in the buffer.\n" << logofs_flush;
   #endif
 
   //
-  // If the channel is interactive flush
-  // the data immediately.
+  // Divide the available data in multiple
+  // messages and encode them one by one.
   //
 
-  if (isInteractive() == 1)
+  if (proxy -> handleAsyncSwitch(fd_) < 0)
   {
-    #if defined(TEST) || defined(INFO)
+    return -1;
+  }
 
-    if (bytes == 0)
+  while ((inputMessage = readBuffer_.getMessage(inputLength)) != NULL)
+  {
+    encodeBuffer.encodeValue(inputLength, 32, 14);
+
+    if (isCompressed() == 1)
     {
-      *logofs << "handleRead: PANIC! No data produced reading "
-              << "from FD#" << fd_ << ".\n" << logofs_flush;
+      unsigned int compressedDataSize = 0;
+      unsigned char *compressedData   = NULL;
 
-      HandleCleanup();
+      if (handleCompress(encodeBuffer, inputOpcode, 0,
+                             inputMessage, inputLength, compressedData,
+                                 compressedDataSize) < 0)
+      {
+        return -1;
+      }
+    }
+    else
+    {
+      encodeBuffer.encodeMemory(inputMessage, inputLength);
     }
 
+    int bits = encodeBuffer.diffBits();
+
+    #if defined(TEST) || defined(OPCODES)
+    *logofs << "handleRead: Handled generic data for FD#" << fd_
+            << ". " << inputLength << " bytes in, " << bits << " bits ("
+            << ((float) bits) / 8 << " bytes) out.\n" << logofs_flush;
     #endif
 
-    #ifdef TEST
-    *logofs << "handleRead: WARNING! Requesting flush because "
-            << "of interactive data produced for FD#" << fd_
-            << ".\n" << logofs_flush;
+    addProtocolBits(inputLength << 3, bits);
+
+    if (isPrioritized() == 1)
+    {
+      priority_++;
+    }
+
+  } // End of while ((inputMessage = readBuffer_.getMessage(inputLength)) != NULL) ...
+
+  //
+  // All data has been read from the read buffer.
+  // We still need to mark the end of the encode
+  // buffer just before sending the frame. This
+  // allows us to accomodate multiple reads in
+  // a single frame.
+  //
+
+  if (priority_ > 0)
+  {
+    #if defined(TEST) || defined(INFO)
+    *logofs << "handleRead: WARNING! Requesting flush "
+            << "because of " << priority_ << " prioritized "
+            << "messages for FD#" << fd_ << ".\n"
+            << logofs_flush;
+    #endif
+
+    if (proxy -> handleAsyncPriority() < 0)
+    {
+      return -1;
+    }
+
+    //
+    // Reset the priority flag.
+    //
+
+    priority_ = 0;
+  }
+
+  //
+  // Flush if we produced enough data.
+  //
+
+  if (proxy -> canAsyncFlush() == 1)
+  {
+    #if defined(TEST) || defined(INFO)
+    *logofs << "handleRead: WARNING! Requesting flush "
+            << "because of enough data or timeout on the "
+            << "proxy link.\n" << logofs_flush;
     #endif
 
     if (proxy -> handleAsyncFlush() < 0)
@@ -324,11 +253,25 @@ int GenericChannel::handleRead(EncodeBuffer &encodeBuffer)
     }
   }
 
+  #if defined(TEST) || defined(INFO)
+
+  if (transport_ -> pending() != 0 ||
+          readBuffer_.checkMessage() != 0)
+  {
+    *logofs << "handleRead: PANIC! Buffer for X descriptor FD#"
+            << fd_ << " has " << transport_ -> pending()
+            << " bytes to read.\n" << logofs_flush;
+
+    HandleCleanup();
+  }
+
+  #endif
+
   //
   // Reset the read buffer.
   //
 
-  readBuffer_.partialReset();
+  readBuffer_.fullReset();
 
   return 1;
 }
@@ -382,7 +325,7 @@ int GenericChannel::handleWrite(const unsigned char *message, unsigned int lengt
     if (isCompressed() == 1)
     {
       if (writeBuffer_.getAvailable() < outputLength ||
-              (int) outputLength >= control -> TransportWriteThreshold)
+              (int) outputLength >= control -> TransportFlushBufferSize)
       {
         #ifdef DEBUG
         *logofs << "handleWrite: Using scratch buffer for "
@@ -451,74 +394,6 @@ int GenericChannel::handleWrite(const unsigned char *message, unsigned int lengt
 // Other members.
 //
 
-int GenericChannel::handleProxyEvents()
-{
-  //
-  // Check if we need to flush because of
-  // prioritized data.
-  //
-
-  if (priority_ > 0)
-  {
-    #if defined(TEST) || defined(INFO)
-    *logofs << "handleProxyEvents: WARNING! Requesting flush "
-            << "because of " << priority_ << " prioritized "
-            << "messages for FD#" << fd_ << ".\n"
-            << logofs_flush;
-    #endif
-
-    if (proxy -> handleAsyncPriority() < 0)
-    {
-      return -1;
-    }
-
-    //
-    // Reset the priority flag.
-    //
-
-    priority_ = 0;
-  }
-
-  //
-  // Flush if we produced enough data.
-  //
-
-  if (proxy -> canAsyncFlush() == 1)
-  {
-    #if defined(TEST) || defined(INFO)
-    *logofs << "handleProxyEvents: WARNING! Requesting flush "
-            << "because of enough data or timeout on the "
-            << "proxy link.\n" << logofs_flush;
-    #endif
-
-    if (proxy -> handleAsyncFlush() < 0)
-    {
-      return -1;
-    }
-  }
-
-  //
-  // Check if we can continue reading.
-  //
-
-  if (proxy -> canRead(fd_) == 0)
-  {
-    #if defined(TEST) || defined(INFO)
-    *logofs << "handleProxyEvents: WARNING! Giving up because of "
-            << "congestion on the proxy link.\n"
-            << logofs_flush;
-    #endif
-
-    return 1;
-  }
-
-  //
-  // Keep encoding messages.
-  //
-
-  return 0;
-}
-
 int GenericChannel::handleCompletion(EncodeBuffer &encodeBuffer)
 {
   //
@@ -560,14 +435,14 @@ int GenericChannel::handleConfiguration()
   #endif
 
   readBuffer_.setSize(control -> GenericInitialReadSize,
-                          control -> GenericMaximumReadSize);
+                          control -> GenericMaximumBufferSize);
 
   writeBuffer_.setSize(control -> TransportGenericBufferSize,
-                           control -> TransportGenericBufferLimit,
+                           control -> TransportGenericBufferThreshold,
                                control -> TransportMaximumBufferSize);
 
   transport_ -> setSize(control -> TransportGenericBufferSize,
-                            control -> TransportGenericBufferLimit,
+                            control -> TransportGenericBufferThreshold,
                                 control -> TransportMaximumBufferSize);
 
   return 1;
@@ -580,7 +455,6 @@ int GenericChannel::handleFinish()
           << fd_ << ".\n" << logofs_flush;
   #endif
 
-  pending_    = 0;
   congestion_ = 0;
   priority_   = 0;
 
