@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -52,7 +52,8 @@ class GenericChannel : public Channel
 
   virtual ~GenericChannel();
 
-  virtual int handleRead(EncodeBuffer &encodeBuffer);
+  virtual int handleRead(EncodeBuffer &encodeBuffer, const unsigned char *message,
+                             unsigned int length);
 
   virtual int handleWrite(const unsigned char *message, unsigned int length);
 
@@ -103,11 +104,11 @@ class GenericChannel : public Channel
 
   virtual int handleFinish();
 
-  virtual int handleNotify(T_notification_type type)
+  virtual int handleAsyncEvents()
   {
     return 0;
   }
-    
+
   virtual int needSplit() const
   {
     return 0;
@@ -118,17 +119,6 @@ class GenericChannel : public Channel
     return 0;
   }
 
-  virtual int needLimit() const
-  {
-    return (transport_ -> length() >=
-                control -> TransportGenericBufferLimit);
-  }
-
-  virtual int getLimit() const
-  {
-    return (control -> TransportGenericBufferLimit);
-  }
-
   virtual T_channel_type getType() const = 0;
 
   //
@@ -140,30 +130,9 @@ class GenericChannel : public Channel
   protected:
 
   //
-  // Model generic channels' encoding and
-  // decoding policy.
-  //
-
-  virtual int isCompressed() = 0;
-
-  //
-  // Determine the flush policy for this
-  // channel.
-  //
-
-  virtual int isPrioritized() = 0;
-
-  //
-  // Returns true if the channel is chatty
-  // and so it is better to keep reading
-  // as long as there is more data.
-  //
-
-  virtual int isInteractive() = 0;
-
-  //
-  // Generic channel are put in congestion state as
-  // soon as the socket is blocked for write.
+  // Generic channels are considered to be
+  // in congestion state as soon as the
+  // socket is blocked for write.
   //
 
   virtual int isCongested()
@@ -171,29 +140,32 @@ class GenericChannel : public Channel
     return (transport_ -> blocked() == 1);
   }
 
-  //
-  // Generic channels are considered not reliable.
-  //
-
   virtual int isReliable()
   {
     return 0;
   }
 
   //
-  // Register protocol bits for
+  // Model generic channels' encoding and
+  // decoding policy.
+  //
+
+  virtual int isCompressed() = 0;
+
+  //
+  // Return true if the channel contains
+  // time sensitive data.
+  //
+
+  virtual int isPrioritized() = 0;
+
+  //
+  // Record the protocol bits for the
   // specific service.
   //
 
   virtual void addProtocolBits(unsigned int bitsIn, unsigned int bitsOut) = 0;
 
-  //
-  // Check if it's time to give up reading
-  // from the channel.
-  //
-
-  int handleProxyEvents();
-
   //
   // Channel's own read buffer.
   //
@@ -237,15 +209,15 @@ class CupsChannel : public GenericChannel
 
   virtual int isCompressed()
   {
-    return 1;
-  }
+    if (control -> isProtoStep8() == 0)
+    {
+      return 1;
+    }
 
-  virtual int isPrioritized()
-  {
     return 0;
   }
 
-  virtual int isInteractive()
+  virtual int isPrioritized()
   {
     return 0;
   }
@@ -280,15 +252,15 @@ class SmbChannel : public GenericChannel
 
   virtual int isCompressed()
   {
-    return 1;
-  }
+    if (control -> isProtoStep8() == 0)
+    {
+      return 1;
+    }
 
-  virtual int isPrioritized()
-  {
     return 0;
   }
 
-  virtual int isInteractive()
+  virtual int isPrioritized()
   {
     return 0;
   }
@@ -331,20 +303,15 @@ class MediaChannel : public GenericChannel
   }
 
   //
-  // We may reduce the latency on the media
-  // channels by setting them as prioritized
-  // but this would take away bandwidth from
+  // Reduce the latency of media channels
+  // by setting them as prioritized, even
+  // if this will take away bandwidth from
   // the X channels.
   //
 
   virtual int isPrioritized()
   {
-    return 0;
-  }
-
-  virtual int isInteractive()
-  {
-    return 0;
+    return 1;
   }
 
   virtual void addProtocolBits(unsigned int bitsIn,
@@ -377,15 +344,15 @@ class HttpChannel : public GenericChannel
 
   virtual int isCompressed()
   {
-    return 1;
-  }
+    if (control -> isProtoStep8() == 0)
+    {
+      return 1;
+    }
 
-  virtual int isPrioritized()
-  {
     return 0;
   }
 
-  virtual int isInteractive()
+  virtual int isPrioritized()
   {
     return 0;
   }
@@ -420,15 +387,15 @@ class FontChannel : public GenericChannel
 
   virtual int isCompressed()
   {
-    return 1;
-  }
+    if (control -> isProtoStep8() == 0)
+    {
+      return 1;
+    }
 
-  virtual int isPrioritized()
-  {
     return 0;
   }
 
-  virtual int isInteractive()
+  virtual int isPrioritized()
   {
     return 1;
   }
@@ -471,11 +438,6 @@ class SlaveChannel : public GenericChannel
     return 0;
   }
 
-  virtual int isInteractive()
-  {
-    return 0;
-  }
-
   virtual void addProtocolBits(unsigned int bitsIn,
                                    unsigned int bitsOut)
   {
