@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -24,6 +24,15 @@
 #undef  TEST
 #undef  DEBUG
 
+unsigned int GenericReadBuffer::suggestedLength(unsigned int pendingLength)
+{
+  //
+  // Always read the initial read size.
+  //
+
+  return 0;
+}  
+
 int GenericReadBuffer::locateMessage(const unsigned char *start,
                                          const unsigned char *end,
                                              unsigned int &controlLength,
@@ -40,8 +49,7 @@ int GenericReadBuffer::locateMessage(const unsigned char *start,
   #ifdef TEST
   *logofs << "GenericReadBuffer: Locating message for FD#"
           << transport_ -> fd() << " with " << size
-          << " bytes and remaining " << remaining_
-          << ".\n" << logofs_flush;
+          << " bytes.\n" << logofs_flush;
   #endif
 
   if (size == 0)
