@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -21,9 +21,8 @@
 #include "Misc.h"
 #include "Unpack.h"
 
-int UnpackJpeg(T_geometry *geometry, unsigned char method,
-                   unsigned char *srcData, int srcSize, int dstBpp,
-                       int dstWidth, int dstHeight, unsigned char *dstData,
-                           int dstSize, int byteOrder);
+int UnpackJpeg(T_geometry *geometry, unsigned char method, unsigned char *srcData,
+                   int srcSize, int dstBpp, int dstWidth, int dstHeight,
+                       unsigned char *dstData, int dstSize);
 
 #endif /* Jpeg_H */
