@@ -16,12 +16,13 @@
 /**************************************************************************/
 
 #include <stdio.h>
-#include <fstream.h>
 #include <unistd.h>
 #include <string.h>
 
 #include <algorithm>
 
+#include "Misc.h"
+
 //
 // We need channel's cache data.
 //
