@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -96,9 +96,7 @@ class Message
   {
     hits_  = 0;
     last_  = 0;
-
     locks_ = 0;
-    keep_  = 0;
 
     size_   = 0;
     c_size_ = 0;
@@ -125,9 +123,7 @@ class Message
 
     hits_  = message.hits_;
     last_  = message.last_;
-
     locks_ = message.locks_;
-    keep_  = message.keep_;
 
     data_ = message.data_;
 
@@ -230,14 +226,7 @@ class Message
   // that have been split. 
   //
 
-  char locks_;
-
-  //
-  // Mark messages that have been
-  // cached at session startup.
-  //
-
-  char keep_;
+  short int locks_;
 
   //
   // This is the MD5 checksum.
@@ -805,12 +794,6 @@ class MessageStore
     return message -> hits_;
   }
 
-  //
-  // Mark message to be retained in repository.
-  //
-
-  int keep(const int position);
-
   //
   // Gives a 'weight' to the cached message. A zero
   // value means object can be safely removed. A value
@@ -1019,13 +1002,6 @@ class MessageStore
 
   md5_state_t *md5_state_;
 
-  //
-  // How many messages have been marked
-  // to be retained in repository.
-  //
-
-  int kept_;
-
   private:
 
   //
