@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -50,24 +50,12 @@ extern "C" {
 #define NX_ALERT_LOCAL                  1
 
 #define NX_HANDLER_FLUSH                0
-#define NX_HANDLER_CONGESTION           1
-#define NX_HANDLER_SYNCHRONIZATION      2
-#define NX_HANDLER_STATISTICS           3
-
-#define NX_CONGESTION_BEGIN             1
-#define NX_CONGESTION_END               0
-
-#define NX_SYNCHRONIZATION_BEGIN        1
-#define NX_SYNCHRONIZATION_END          0
+#define NX_HANDLER_STATISTICS           1
 
 #define NX_STATISTICS_PARTIAL           0
 #define NX_STATISTICS_TOTAL             1
 
-#define NX_FLUSH_SYNC                   1
-#define NX_FLUSH_LINK                   2
-#define NX_FLUSH_IDLE                   3
-
-#define NX_CHANNEL_X                    0
+#define NX_CHANNEL_X11                  0
 #define NX_CHANNEL_CUPS                 1
 #define NX_CHANNEL_SMB                  2
 #define NX_CHANNEL_MEDIA                3
@@ -248,50 +236,27 @@ extern int NXTransDestroy(int fd);
 extern int NXTransSignal(int signal, int action);
 
 /*
- * Return true if the transport is in congestion state.
+ * Return a value between 0 and 9 indicating the congestion level
+ * based on the tokens still available. A value of 9 means that
+ * the link is congested and no further data can be sent.
  */
 
 extern int NXTransCongestion(int fd);
 
 /*
  * Let the application to be notified by the proxy when an event oc-
- * curs. The parameter, as set at the time the handler is set, is
- * passed each time to the callback function. The parameter is presu-
- * mably the display, given that at the present moment the NX trans-
- * port doesn't have access to the display structure and so wouldn't
- * be able to determine the display to pass to the callback function.
+ * curs. The parameter, as set at the time the handler is installed,
+ * is passed each time to the callback function. The parameter is
+ * presumably the display pointer, given that at the present moment
+ * the NX transport doesn't have access to the display structure and
+ * so wouldn't be able to determine the display to pass to the call-
+ * back function.
  *
- * NX_HANDLER_FLUSH:      The handler function is called when the
- *                        proxy needs to flush the proxy link.
+ * NX_HANDLER_FLUSH:      The handler function is called when some
+ *                        more data has been written to the proxy
+ *                        link.
  *
- * The reason is currently unused and is always set to 0.
- *
- * NX_HANDLER_CONGESTION: The handler function is called when the
- *                        proxy is entering or exiting the congest-
- *                        ion state.
- *
- * The reason can be:
- *
- * NX_CONGESTION_BEGIN:   The proxy entered in congestion state.
- *
- * NX_CONGESTION_END:     The link became newly available.
- *
- * The reason can be determined by agents by using the NXBeginCong-
- * estion and NXEndCongestion values defined in NXvars.h.
- *
- * NX_HANDLER_SYNCHRONIZATION: The handler is called when it is
- *                             possible to use the available band-
- *                             width to synchronize X objects that
- *                             are corrupted or incomplete.
- *
- * The reason can be:
- *
- * NX_SYNCHRONIZATION_BEGIN:   The synchronizationis allowed.
- *
- * NX_SYNCHRONIZATION_END:     The synchronizationis must stop.
- *
- * The reason can be determined by agents by using the NXBeginSynch-
- * ronization and NXEndSynchronization values defined in NXvars.h.
+ * The data is the number of bytes written.
  *
  * NX_HANDLER_STATISTICS: This handler is called to let the agent
  *                        include arbitrary data in the transport
@@ -302,9 +267,9 @@ extern int NXTransCongestion(int fd);
  *                        ed string will have to be filled by the
  *                        agent with its statistics data.
  *
- * The reason can be NX_STATISTICS_PARTIAL or NX_STATISTICS_TOTAL. The
- * reason can be determined by agents by using the  NXStatisticsPartial
- * and NXStatisticsTotal values defined in NXvars.h.
+ * The data can be NX_STATISTICS_PARTIAL or NX_STATISTICS_TOTAL. The
+ * agent can refer to the value by using the  NXStatisticsPartial and
+ * NXStatisticsTotal constants defined in NXvars.h.
  *
  * Note that these interfaces are used by Xlib and nxcompext. Agents
  * should never call these interfaces directly, but use the nxcompext
@@ -338,27 +303,10 @@ extern int NXTransFlushable(int fd);
 
 /*
  * Tell to the NX transport to write all the accumulated data to the
- * remote proxy. The type parameter can be:
- *
- * NX_FLUSH_SYNC:    If a sync flush is requested, the proxy will
- *                   force the remote peer to flush all the data un-
- *                   til past the sequence number matching the sequ-
- *                   ence number of the last request written for the
- *                   agent. It's advisable to request a sync flush
- *                   whenever the flush policy is set to deferred
- *                   writes and the agent is going to block waiting
- *                   for a reply.
- *
- * NX_FLUSH_LINK:    Normal flush. Enough data was produced for the
- *                   proxy link or the agent is waiting for more
- *                   data coming from the X server.
- *
- * NX_FLUSH_IDLE:    Inform the proxy that the agent is idle and so
- *                   the proxy can use the available bandwidth to
- *                   encode low priority data. 
+ * remote proxy.
  */
 
-extern int NXTransFlush(int fd, int type);
+extern int NXTransFlush(int fd);
 
 /*
  * Create a new channel of the given type. It returns 1 on success,
@@ -462,6 +410,13 @@ extern int NXTransChannel(int fd, int channelfd, int type);
 
 extern const char *NXTransFile(int type);
 
+/*
+ * Return the time in milliseconds elapsed since the last call to this
+ * same function.
+ */
+
+extern long NXTransTime(void);
+
 /*
  * Other interfaces to the internal transport functions.
  */
