@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -26,6 +26,13 @@ extern "C" {
 #include <X11/Xmd.h>
 #include <X11/Xproto.h>
 
+/*
+ * Force the size to match the wire protocol.
+ */
+ 
+#define Drawable CARD32
+#define GContext CARD32
+
 #define sz_xNXGetControlParametersReq           4
 #define sz_xNXGetCleanupParametersReq           4
 #define sz_xNXGetImageParametersReq             4
@@ -81,8 +88,8 @@ typedef struct _NXGetControlParametersReply {
     CARD8  remoteMajor;
     CARD8  remoteMinor;
     CARD8  remotePatch;
-    CARD16 frameTimeout B16;
-    CARD16 pingTimeout B16;
+    CARD16 splitTimeout B16;
+    CARD16 motionTimeout B16;
     CARD8  splitMode;
     CARD8  pad1;
     CARD32 splitSize B32;
@@ -411,26 +418,6 @@ typedef struct _NXFreeUnpackReq {
 #define NXEndSplitNotify                4
 #define NXEmptySplitNotify              5
 
-/*
- * Sent to the application by the transport at
- * the beginning and at the end of a proxy reset.
- * This usually implies a new connection between
- * the proxies.
- */
-
-#define NXResetNotify                   6
-
-/*
- * Sent to the application by the transport when
- * a congestion is detected on the proxy link. The
- * applications should stop producing data for the
- * transport until the condition is ceased. Event
- * is not sent if the agent has registered a con-
- * gestion handler function.
- */
-
-#define NXCongestionNotify              7
-
 /*
  * Notifications of collect events. These events
  * don't come from the NX transport but are put
@@ -442,22 +429,8 @@ typedef struct _NXFreeUnpackReq {
 #define NXCollectGrabPointerNotify      10
 #define NXCollectInputFocusNotify       11
 
-/*
- * Sent to the application by the transport when
- * the proxy link needs to be flushed. Event is
- * not sent if the agent has registered a flush
- * handler function.
- */
-
-#define NXFlushNotify                   12
-
-/*
- * Sent to the application when the agent can use
- * the available bandwidth to synchronize the X
- * objects that are corrupted or incomplete.
- */
-
-#define NXSynchronizationNotify         13
+#undef Drawable
+#undef GContext
 
 #ifdef __cplusplus
 }
