@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -73,9 +73,6 @@ class OpcodeStore
   unsigned char shapeExtension;
   unsigned char renderExtension;
 
-  unsigned char resetNotify;
-  unsigned char congestionNotify;
-
   unsigned char noSplitNotify;
   unsigned char startSplitNotify;
   unsigned char commitSplitNotify;
