@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -39,38 +39,6 @@ const ColorMask Mask256KTrueColor = { 252, 1,  252, 1 };
 const ColorMask Mask2MTrueColor   = { 255, 0,  254, 1 };
 const ColorMask Mask16MTrueColor  = { 255, 0,  255, 0 };
 
-const SplitGeometry GeometrySmall  = { 32,    32,    32,    32 };
-const SplitGeometry GeometryMedium = { 80,    80,    80,    80 };
-const SplitGeometry GeometryBig    = { 128,   128,   128,   128 };
-const SplitGeometry GeometryHuge   = { 16384, 16384, 16384, 16384 };
-
-const SplitGeometry *MethodSplitGeometry(unsigned int method)
-{
-  switch (method)
-  {
-    case SPLIT_GEOMETRY_SMALL:
-    {
-      return &GeometrySmall;
-    }
-    case SPLIT_GEOMETRY_MEDIUM:
-    {
-      return &GeometryMedium;
-    }
-    case SPLIT_GEOMETRY_BIG:
-    {
-      return &GeometryBig;
-    }
-    case SPLIT_GEOMETRY_HUGE:
-    {
-      return &GeometryHuge;
-    }
-    default:
-    {
-      return 0;
-    }
-  }
-}
-
 const ColorMask *MethodColorMask(unsigned int method)
 {
   switch (method)
@@ -127,122 +95,71 @@ int MethodBitsPerPixel(unsigned int method)
   switch (method)
   {
     case PACK_MASKED_8_COLORS:
-    case PACK_TIGHT_8_COLORS:
     case PACK_JPEG_8_COLORS:
     case PACK_PNG_8_COLORS:
-    case PACK_PNG_JPEG_8_COLORS:
     {
       return 8;
     }
     case PACK_MASKED_64_COLORS:
-    case PACK_TIGHT_64_COLORS:
     case PACK_JPEG_64_COLORS:
     case PACK_PNG_64_COLORS:
-    case PACK_PNG_JPEG_64_COLORS:
     {
       return 8;
     }
     case PACK_MASKED_256_COLORS:
-    case PACK_TIGHT_256_COLORS:
     case PACK_JPEG_256_COLORS:
     case PACK_PNG_256_COLORS:
-    case PACK_PNG_JPEG_256_COLORS:
     {
       return 8;
     }
     case PACK_MASKED_512_COLORS:
-    case PACK_TIGHT_512_COLORS:
     case PACK_JPEG_512_COLORS:
     case PACK_PNG_512_COLORS:
-    case PACK_PNG_JPEG_512_COLORS:
     {
       return 16;
     }
     case PACK_MASKED_4K_COLORS:
-    case PACK_TIGHT_4K_COLORS:
     case PACK_JPEG_4K_COLORS:
     case PACK_PNG_4K_COLORS:
-    case PACK_PNG_JPEG_4K_COLORS:
     {
       return 16;
     }
     case PACK_MASKED_32K_COLORS:
-    case PACK_TIGHT_32K_COLORS:
     case PACK_JPEG_32K_COLORS:
     case PACK_PNG_32K_COLORS:
-    case PACK_PNG_JPEG_32K_COLORS:
     {
       return 16;
     }
     case PACK_MASKED_64K_COLORS:
-    case PACK_TIGHT_64K_COLORS:
     case PACK_JPEG_64K_COLORS:
     case PACK_PNG_64K_COLORS:
-    case PACK_PNG_JPEG_64K_COLORS:
     {
       return 16;
     }
     case PACK_MASKED_256K_COLORS:
-    case PACK_TIGHT_256K_COLORS:
     case PACK_JPEG_256K_COLORS:
     case PACK_PNG_256K_COLORS:
-    case PACK_PNG_JPEG_256K_COLORS:
     {
       return 24;
     }
     case PACK_MASKED_2M_COLORS:
-    case PACK_TIGHT_2M_COLORS:
     case PACK_JPEG_2M_COLORS:
     case PACK_PNG_2M_COLORS:
-    case PACK_PNG_JPEG_2M_COLORS:
     {
       return 24;
     }
     case PACK_MASKED_16M_COLORS:
-    case PACK_TIGHT_16M_COLORS:
     case PACK_JPEG_16M_COLORS:
     case PACK_PNG_16M_COLORS:
-    case PACK_PNG_JPEG_16M_COLORS:
     {
       return 24;
     }
+    case PACK_BITMAP_16M_COLORS:
     case PACK_RGB_16M_COLORS:
     case PACK_RLE_16M_COLORS:
     {
       return 24;
     }
-    case PACK_RDP_PLAIN_256_COLORS:
-    case PACK_RDP_COMPRESSED_256_COLORS:
-    {
-      return 8;
-    }
-    case PACK_RDP_PLAIN_32K_COLORS:
-    case PACK_RDP_COMPRESSED_32K_COLORS:
-    {
-      return 16;
-    }
-    case PACK_RDP_PLAIN_64K_COLORS:
-    case PACK_RDP_COMPRESSED_64K_COLORS:
-    {
-      return 16;
-    }
-    case PACK_RDP_PLAIN_16M_COLORS:
-    case PACK_RDP_COMPRESSED_16M_COLORS:
-    {
-      return 24;
-    }
-    case PACK_RFB_TIGHT_PLAIN:
-    {
-      return 32;
-    }
-    case PACK_RFB_TIGHT_COMPRESSED:
-    {
-      return 32;
-    }
-    case PACK_RFB_HEXTILE:
-    {
-      return 32;
-    }
     default:
     {
       return 0;
