@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -54,7 +54,7 @@ int PolyLineStore::parseIdentity(Message *message, const unsigned char *buffer,
   *logofs << name() << ": Parsed Identity for message at " << this << ".\n" << logofs_flush;
   #endif
 
-  return true;
+  return 1;
 }
 
 int PolyLineStore::unparseIdentity(const Message *message, unsigned char *buffer,
@@ -75,7 +75,7 @@ int PolyLineStore::unparseIdentity(const Message *message, unsigned char *buffer
   *logofs << name() << ": Unparsed identity for message at " << this << ".\n" << logofs_flush;
   #endif
 
-  return true;
+  return 1;
 }
 
 void PolyLineStore::dumpIdentity(const Message *message) const
@@ -93,6 +93,10 @@ void PolyLineStore::dumpIdentity(const Message *message) const
 void PolyLineStore::identityChecksum(const Message *message, const unsigned char *buffer,
                                          unsigned int size, int bigEndian) const
 {
+  if (control -> isProtoStep8() == 1)
+  {
+    md5_append(md5_state_, buffer + 1, 1);
+  }
 }
 
 void PolyLineStore::updateIdentity(EncodeBuffer &encodeBuffer, const Message *message,
@@ -104,7 +108,10 @@ void PolyLineStore::updateIdentity(EncodeBuffer &encodeBuffer, const Message *me
 
   ClientCache *clientCache = (ClientCache *) channelCache;
 
-  encodeBuffer.encodeBoolValue((unsigned int) polyLine -> mode);
+  if (control -> isProtoStep8() == 0)
+  {
+    encodeBuffer.encodeBoolValue((unsigned int) polyLine -> mode);
+  }
 
   #ifdef TEST
   *logofs << name() << ": Encoding value " << polyLine -> drawable
@@ -134,9 +141,12 @@ void PolyLineStore::updateIdentity(DecodeBuffer &decodeBuffer, const Message *me
 
   unsigned int value;
 
-  decodeBuffer.decodeBoolValue(value);
+  if (control -> isProtoStep8() == 0)
+  {
+    decodeBuffer.decodeBoolValue(value);
 
-  polyLine -> mode = value;
+    polyLine -> mode = value;
+  }
 
   decodeBuffer.decodeXidValue(value, clientCache -> drawableCache);
 
