@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -72,11 +72,16 @@ class Agent;
 // code_configuration_request,
 // code_configuration_reply.
 //
-// The code_new_aux_connection code (to open
-// the former 'keybd' connections) should not
+// These are for compatibility with
+// old versions.
+//
+// code_sync_request,
+// code_sync_reply,
+//
+// The code_new_aux_connection should not
 // be used anymore. Auxiliary X connections
-// are opened as normal X channels since the
-// 1.5.0 version.
+// are treated as normal X channels since
+// version 1.5.0.
 //
 
 typedef enum
@@ -211,17 +216,13 @@ class Proxy
 
   int handleRead();
 
-  int handleRead(int fd);
+  int handleRead(int fd, const char *data = NULL, int size = 0);
 
   int handleEvents();
 
-  int handleFlush(T_flush type);
+  int handleFlush();
 
-  int handleFlush(T_flush type, int fd);
-
-  int handlePartial();
-
-  int handleSync();
+  int handleFlush(int fd);
 
   int handlePing();
 
@@ -233,8 +234,6 @@ class Proxy
 
   int handleAlert(int alert);
 
-  int handleNotify(T_notification_type type);
-
   int handleRotate()
   {
     activeChannels_.rotate();
@@ -298,6 +297,13 @@ class Proxy
 
   int handleCloseAllListeners();
 
+  //
+  // Called when the loop has replaced
+  // or closed a previous alert.
+  //
+
+  void handleResetAlert();
+
   //
   // Handle the persistent cache.
   //
@@ -379,7 +385,6 @@ class Proxy
   typedef struct
   {
     int size;
-    int threshold;
     int limit;
 
     int bytes;
@@ -421,7 +426,7 @@ class Proxy
 
   int handleTokenReplyFromProxy(T_proxy_token &token, int count);
 
-  int handleSyncFromProxy();
+  int handleSyncFromProxy(int channelId);
 
   int handleSwitch(int channelId);
 
@@ -429,7 +434,13 @@ class Proxy
 
   int handleControlFromProxy(const unsigned char *message);
 
-  int handleSync(int channelId);
+  //
+  // Interleave reads of the X server
+  // events while writing data to the
+  // remote proxy.
+  //
+
+  virtual int handleAsyncEvents() = 0;
 
   //
   // Timer related functions.
@@ -503,34 +514,33 @@ class Proxy
   int shouldFlush() const
   {
     if ((int) ((encodeBuffer_.getLength() +
-            controlLength_ + 1) / control ->
+            controlLength_) / statistics ->
                 getStreamRatio()) >= control -> TokenSize)
     {
       #if defined(TEST) || defined(INFO) || defined(FLUSH)
       *logofs << "Proxy: FLUSH! Requesting a flush with "
-              << (encodeBuffer_.getLength() + controlLength_ + 1)
-              << " bytes and stream ratio " << (double) control ->
+              << (encodeBuffer_.getLength() + controlLength_)
+              << " bytes and stream ratio " << (double) statistics ->
                  getStreamRatio() << ".\n" << logofs_flush;
       #endif
 
       return 1;
     }
 
-    return 0;
-  }
+    #if defined(TEST) || defined(INFO) || defined(FLUSH)
+    *logofs << "Proxy: Not requesting a flush with "
+            << (encodeBuffer_.getLength() + controlLength_)
+            << " bytes and stream ratio " << (double) statistics ->
+               getStreamRatio() << ".\n" << logofs_flush;
+    #endif
 
-  int shouldSync(int sequence) const
-  {
-    return (currentSync_ >= 0 &&
-                (sequence >= currentSync_ ||
-                    currentSync_ - sequence >= 32768));
+    return 0;
   }
 
   int needDrain() const
   {
-    return ((congestion_ == 1 || transport_ -> length() >
-                control -> TransportProxyBufferLimit) &&
-                    draining_ == 0);
+    return (congestion_ == 1 || transport_ -> length() >
+                control -> TransportProxyBufferThreshold);
   }
 
   int getFd() const
@@ -606,7 +616,7 @@ class Proxy
   }
 
   //
-  // Remap these calls to the IO buffers.
+  // Interfaces to the transport buffers.
   //
 
   int getLength(int fd) const
@@ -630,7 +640,7 @@ class Proxy
   {
     if (fd == fd_)
     {
-      return pending_;
+      return transport_ -> pending();
     }
 
     int channelId = getChannel(fd);
@@ -640,53 +650,13 @@ class Proxy
       return 0;
     }
 
-    return channels_[channelId] -> getPending();
-  }
-
-  int setPending(int fd)
-  {
-    if (fd == fd_)
-    {
-      pending_ = 1;
-    }
-    else
-    {
-      int channelId = getChannel(fd);
-
-      if (channelId < 0 || channels_[channelId] == NULL)
-      {
-        #if defined(TEST) || defined(INFO)
-
-        #ifdef PANIC
-        *logofs << "Proxy: PANIC! Can't set buffer for "
-                << "descriptor FD#" << fd_ << " as pending.\n"
-                << logofs_flush;
-        #endif
-
-        cerr << "Error" << ": Can't set buffer for "
-             << "descriptor FD#" << fd_ << " as pending.\n";
-
-        HandleCleanup();
-
-        #endif
-
-        return -1;
-      }
-
-      #ifdef TEST
-      *logofs << "Proxy: Setting buffer for descriptor FD#"
-              << fd_ << " to be pending.\n" << logofs_flush;
-      #endif
-
-      channels_[channelId] -> setPending();
-    }
-
-    return 1;
+    return transports_[channelId] -> pending();
   }
 
   //
-  // Check if the proxy or the given channel has
-  // data in buffers because of a blocking write.
+  // Check if the proxy or the given channel
+  // has data in the buffer because of a
+  // blocking write.
   //
 
   int getBlocked(int fd) const
@@ -728,11 +698,17 @@ class Proxy
     return transports_[channelId] -> readable();
   }
 
+  //
+  // Return a vale between 0 and 9 in the case
+  // of the proxy descriptor.
+  //
+
   int getCongestion(int fd) const
   {
     if (fd == fd_)
     {
-      return isCongested();
+      return (agent_ != nothing && congestions_[agent_] == 1 ? 9 :
+                  (int) statistics -> getCongestionInFrame());
     }
 
     int channelId = getChannel(fd);
@@ -746,8 +722,8 @@ class Proxy
   }
 
   //
-  // Let statistics class to get info from
-  // message stores.
+  // Let the statistics class get info
+  // from the message stores.
   //
 
   const ClientStore * const getClientStore() const
@@ -766,21 +742,6 @@ class Proxy
   // loop.
   //
 
-  int canAsyncRead() const
-  {
-    return canRead();
-  }
-
-  int canAsyncFlush() const
-  {
-    return shouldFlush();
-  }
-
-  int canAsyncSync(int sequence) const
-  {
-    return shouldSync(sequence);
-  }
-
   int handleAsyncRead(int fd)
   {
     return handleRead(fd);
@@ -788,7 +749,16 @@ class Proxy
 
   int handleAsyncCongestion(int fd)
   {
-    return handleControl(code_begin_congestion, getChannel(fd));
+    int channelId = getChannel(fd);
+
+    return handleControl(code_begin_congestion, channelId);
+  }
+
+  int handleAsyncDecongestion(int fd)
+  {
+    int channelId = getChannel(fd);
+
+    return handleControl(code_end_congestion, channelId);
   }
 
   int handleAsyncSplit(int fd, Split *split)
@@ -799,43 +769,27 @@ class Proxy
 
   int handleAsyncInit()
   {
-    return handleFlush(flush_if_any);
+    return handleFlush();
   }
 
   int handleAsyncPriority()
   {
     if (control -> FlushPriority == 1)
     {
-      return handleFlush(flush_if_any);
+      return handleFlush();
     }
 
     return 0;
   }
 
+  int canAsyncFlush() const
+  {
+    return shouldFlush();
+  }
+
   int handleAsyncFlush()
   {
-    if (control -> FlushPolicy == policy_immediate)
-    {
-      return handleFlush(flush_if_any);
-    }
-    else if (currentFlush_ != 1)
-    {
-      currentFlush_ = 1;
-
-      return handleNotify(notify_need_flush);
-    }
-
-    return 0;
-  }
-
-  int handleAsyncRead()
-  {
-    return handleRead();
-  }
-
-  int handleAsyncSync(int fd)
-  {
-    return handleSync(getChannel(fd));
+    return handleFlush();
   }
 
   int handleAsyncSwitch(int fd)
@@ -843,27 +797,6 @@ class Proxy
     return handleSwitch(getChannel(fd));
   }
 
-  int handleAsyncFlushCallback()
-  {
-    FlushCallback();
-
-    return 1;
-  }
-
-  int handleAsyncCongestionCallback(T_notification_type type)
-  {
-    CongestionCallback(type);
-
-    return 1;
-  }
-
-  int handleAsyncSynchronizationCallback(T_notification_type type)
-  {
-    SynchronizationCallback(type);
-
-    return 1;
-  }
-
   int handleAsyncKeeperCallback()
   {
     KeeperCallback();
@@ -871,7 +804,6 @@ class Proxy
     return 1;
   }
 
-
   //
   // Internal interfaces used to verify the
   // availability of channels and the proxy
@@ -906,7 +838,7 @@ class Proxy
             channels_[channelId] != NULL &&
                 congestions_[channelId] == 0)
     {
-      if (channels_[channelId] -> getType() == channel_x ||
+      if (channels_[channelId] -> getType() == channel_x11 ||
               tokens_[token_data].remaining > 0 ||
                   channels_[channelId] ->
                       getFinish() == 1)
@@ -1135,34 +1067,6 @@ class Proxy
 
   protected:
 
-  //
-  // Notify the proxy congestion to the
-  // X channels.
-  //
-
-  int isCongested() const
-  {
-    return (currentCongestion_ == 1 ?
-                tokens_[token_control].remaining <=
-                    tokens_[token_control].threshold :
-                        congestion_ == 1);
-  }
-
-  //
-  // Notify that the synchronization is
-  // now possible.
-  //
-
-  int isIdle() const
-  {
-    return (congestion_ == 0 &&
-                tokens_[token_control].remaining >
-                    tokens_[token_control].threshold);
-  }
-
-  void notifyCongestion();
-  void notifySynchronization();
-
   void setSplitTimeout(int channelId);
   void setMotionTimeout(int channelId);
 
@@ -1220,13 +1124,6 @@ class Proxy
   int inputChannel_;
   int outputChannel_;
 
-  //
-  // The first X conection established,
-  // normally the controlling channel.
-  //
-
-  int agentChannel_;
-
   //
   // List of active channels.
   //
@@ -1280,13 +1177,6 @@ class Proxy
 
   int operation_;
 
-  //
-  // True if we have pending messages in
-  // the proxy read buffer.
-  //
-
-  int pending_;
-
   //
   // True if we are currently draining
   // the proxy link.
@@ -1323,53 +1213,36 @@ class Proxy
   int congestion_;
 
   //
-  // Is there any channel at remote end
-  // that's not consuming enough data?
+  // Channels at the remote end that
+  // are not consuming their data.
   //
 
   int congestions_[CONNECTIONS_LIMIT];
 
   //
-  // Is the timer expired.
+  // Is the timer expired?
   //
 
   int timer_;
 
+  //
+  // Did the proxy request an alert?
+  //
+
+  int alert_;
+
+  //
+  // The channel id of the agent.
+  //
+
+  int agent_;
+
   //
   // Token related data.
   //
 
   T_proxy_token tokens_[TOKEN_TYPES];
 
-  //
-  // Sequence counter of the last X request
-  // decoded by agent connection at the time
-  // the sync control code was received by
-  // this proxy.
-  //
-
-  int currentSync_;
-  
-  //
-  // Type of last congestion notification
-  // sent to the X agent.
-  //
-
-  int currentCongestion_;
-
-  //
-  // Current state of agent synchronization.
-  //
-
-  int currentSynchronization_;
-
-  //
-  // Set if the flush request was already
-  // notified to the agent.
-  //
-
-  int currentFlush_;
-
   //
   // Pointer to stream descriptor where
   // proxy is producing statistics.
