@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -59,6 +59,11 @@ PutImageStore::PutImageStore(StaticCompressor *compressor)
   cacheThreshold      = PUTIMAGE_CACHE_THRESHOLD;
   cacheLowerThreshold = PUTIMAGE_CACHE_LOWER_THRESHOLD;
 
+  if (control -> isProtoStep8() == 1)
+  {
+    enableSplit = PUTIMAGE_ENABLE_SPLIT_IF_PROTO_STEP_8;
+  }
+
   messages_ -> resize(cacheSlots);
 
   for (T_messages::iterator i = messages_ -> begin();
@@ -227,7 +232,7 @@ int PutImageStore::parseIdentity(Message *message, const unsigned char *buffer,
   *logofs << name() << ": Parsed identity for message at " << message << ".\n" << logofs_flush;
   #endif
 
-  return true;
+  return 1;
 }
 
 int PutImageStore::unparseIdentity(const Message *message, unsigned char *buffer,
@@ -257,7 +262,7 @@ int PutImageStore::unparseIdentity(const Message *message, unsigned char *buffer
           << message << ".\n" << logofs_flush;
   #endif
 
-  return true;
+  return 1;
 }
 
 void PutImageStore::dumpIdentity(const Message *message) const
