@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -51,6 +51,11 @@
 #define PUTIMAGE_CACHE_THRESHOLD_IF_PACKED               10
 #define PUTIMAGE_CACHE_LOWER_THRESHOLD_IF_PACKED         5
 
+#define PUTIMAGE_CACHE_THRESHOLD_IF_SHADOW               97
+#define PUTIMAGE_CACHE_LOWER_THRESHOLD_IF_SHADOW         90
+
+#define PUTIMAGE_ENABLE_SPLIT_IF_PROTO_STEP_8            0
+
 //
 // The message class.
 //
