@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -54,6 +54,11 @@ PutPackedImageStore::PutPackedImageStore(StaticCompressor *compressor)
   cacheThreshold      = PUTPACKEDIMAGE_CACHE_THRESHOLD;
   cacheLowerThreshold = PUTPACKEDIMAGE_CACHE_LOWER_THRESHOLD;
 
+  if (control -> isProtoStep8() == 1)
+  {
+    enableSplit = PUTPACKEDIMAGE_ENABLE_SPLIT_IF_PROTO_STEP_8;
+  }
+
   messages_ -> resize(cacheSlots);
 
   for (T_messages::iterator i = messages_ -> begin();
@@ -104,16 +109,16 @@ int PutPackedImageStore::encodeIdentity(EncodeBuffer &encodeBuffer, const unsign
   encodeBuffer.encodeXidValue(GetULONG(buffer + 8, bigEndian),
                      clientCache -> gcCache);
   // Method.
-  encodeBuffer.encodeCachedValue(buffer[12], 8,
+  encodeBuffer.encodeCachedValue(*(buffer + 12), 8,
                      clientCache -> methodCache);
   // Format.
-  encodeBuffer.encodeValue(buffer[13], 2);
+  encodeBuffer.encodeValue(*(buffer + 13), 2);
 
   // SrcDepth.
-  encodeBuffer.encodeCachedValue(buffer[14], 8,
+  encodeBuffer.encodeCachedValue(*(buffer + 14), 8,
                      clientCache -> depthCache);
   // DstDepth.
-  encodeBuffer.encodeCachedValue(buffer[15], 8,
+  encodeBuffer.encodeCachedValue(*(buffer + 15), 8,
                      clientCache -> depthCache);
   // SrcLength.
   encodeBuffer.encodeCachedValue(GetULONG(buffer + 16, bigEndian), 24,
@@ -321,7 +326,7 @@ int PutPackedImageStore::parseIdentity(Message *message, const unsigned char *bu
           << message << ".\n" << logofs_flush;
   #endif
 
-  return true;
+  return 1;
 }
 
 int PutPackedImageStore::unparseIdentity(const Message *message, unsigned char *buffer,
@@ -362,7 +367,7 @@ int PutPackedImageStore::unparseIdentity(const Message *message, unsigned char *
           << message << ".\n" << logofs_flush;
   #endif
 
-  return true;
+  return 1;
 }
 
 void PutPackedImageStore::dumpIdentity(const Message *message) const
