@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -34,10 +34,10 @@
 // Set default values.
 //
 
-#define PUTPACKEDIMAGE_ENABLE_CACHE                                  1
-#define PUTPACKEDIMAGE_ENABLE_DATA                                   1
-#define PUTPACKEDIMAGE_ENABLE_SPLIT                                  1
-#define PUTPACKEDIMAGE_ENABLE_COMPRESS                               0
+#define PUTPACKEDIMAGE_ENABLE_CACHE                            1
+#define PUTPACKEDIMAGE_ENABLE_DATA                             1
+#define PUTPACKEDIMAGE_ENABLE_SPLIT                            1
+#define PUTPACKEDIMAGE_ENABLE_COMPRESS                         0
 
 //
 // We can't exceed lenght of 262144 bytes.
@@ -50,8 +50,10 @@
 #define PUTPACKEDIMAGE_CACHE_THRESHOLD                         70
 #define PUTPACKEDIMAGE_CACHE_LOWER_THRESHOLD                   50
 
-#define PUTPACKEDIMAGE_CACHE_THRESHOLD_IF_PACKED_RDP           90
-#define PUTPACKEDIMAGE_CACHE_LOWER_THRESHOLD_IF_PACKED_RDP     70
+#define PUTPACKEDIMAGE_CACHE_THRESHOLD_IF_PACKED_SHADOW        97
+#define PUTPACKEDIMAGE_CACHE_LOWER_THRESHOLD_IF_PACKED_SHADOW  90
+
+#define PUTPACKEDIMAGE_ENABLE_SPLIT_IF_PROTO_STEP_8            0
 
 //
 // The message class.
