@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -22,6 +22,8 @@
 #include "Timestamp.h"
 #include "Transport.h"
 
+#define READ_BUFFER_DEFAULT_SIZE  8192
+
 #define PANIC
 #define WARNING
 #undef  TEST
@@ -31,27 +33,13 @@ class ReadBuffer
 {
   public:
 
-  ReadBuffer(Transport *transport, unsigned int initialReadSize,
-                 unsigned int maximumReadSize);
+  ReadBuffer(Transport *transport);
 
   virtual ~ReadBuffer();
 
-  int setSize(int initialReadSize, int maximumReadSize)
-  {
-    initialReadSize_  = initialReadSize;
-    maximumReadSize_  = maximumReadSize;
+  int readMessage();
 
-    #ifdef TEST
-    *logofs << "ReadBuffer: WARNING! Set buffer parameters to "
-            << initialReadSize_ << "/" << maximumReadSize_
-            << " for object at "<< this << ".\n"
-            << logofs_flush;
-    #endif
-
-    return 1;
-  }
-
-  int readMessage(unsigned int readLength = 0);
+  void readMessage(const unsigned char *message, unsigned int length);
 
   const unsigned char *getMessage(unsigned int &dataLength)
   {
@@ -60,8 +48,7 @@ class ReadBuffer
     return getMessage(controlLength, dataLength);
   }
 
-  const unsigned char *getMessage(unsigned int &controlLength,
-                                      unsigned int &dataLength);
+  const unsigned char *getMessage(unsigned int &controlLength, unsigned int &dataLength);
 
   unsigned int getLength() const
   {
@@ -73,18 +60,13 @@ class ReadBuffer
     return remaining_;
   }
 
-  int waitMessage(int timeout) const
-  {
-    return transport_ -> wait(timeout);
-  }
-
-  void partialReset();
+  int setSize(int initialReadSize, int initialbufferSize);
 
   void fullReset();
 
   //
-  // Check if there is any data
-  // left in the buffer.
+  // Check if there is a complete
+  // message in the buffer.
   //
 
   int checkMessage()
@@ -106,12 +88,19 @@ class ReadBuffer
 
   protected:
 
+  virtual unsigned int suggestedLength(unsigned int pendingLength) = 0;
+
   virtual int locateMessage(const unsigned char *start,
                                 const unsigned char *end,
                                     unsigned int &controlLength,
                                         unsigned int &dataLength,
                                             unsigned int &trailerLength) = 0;
 
+  unsigned char *allocateBuffer(unsigned int newSize);
+
+  void appendBuffer(const unsigned char *message, unsigned int length);
+
+  void convertBuffer();
 
   Transport *transport_;
 
@@ -122,8 +111,10 @@ class ReadBuffer
   unsigned int start_;
   unsigned int remaining_;
 
+  int owner_;
+
   unsigned int initialReadSize_;
-  unsigned int maximumReadSize_;
+  unsigned int maximumBufferSize_;
 };
 
 #endif /* ReadBuffer_H */
