@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -116,17 +116,16 @@ RenderExtensionStore::RenderExtensionStore(StaticCompressor *compressor)
 
   if (control -> isProtoStep7() == 1)
   {
-    cacheSlots          = RENDEREXTENSION_CACHE_SLOTS_IF_PROTO_STEP_7;
-    cacheThreshold      = RENDEREXTENSION_CACHE_THRESHOLD_IF_PROTO_STEP_7;
-    cacheLowerThreshold = RENDEREXTENSION_CACHE_LOWER_THRESHOLD_IF_PROTO_STEP_7;
+    cacheSlots = RENDEREXTENSION_CACHE_SLOTS_IF_PROTO_STEP_7;
   }
   else
   {
-    cacheSlots          = RENDEREXTENSION_CACHE_SLOTS;
-    cacheThreshold      = RENDEREXTENSION_CACHE_THRESHOLD;
-    cacheLowerThreshold = RENDEREXTENSION_CACHE_LOWER_THRESHOLD;
+    cacheSlots = RENDEREXTENSION_CACHE_SLOTS;
   }
 
+  cacheThreshold      = RENDEREXTENSION_CACHE_THRESHOLD;
+  cacheLowerThreshold = RENDEREXTENSION_CACHE_LOWER_THRESHOLD;
+
   opcode_ = X_NXInternalRenderExtension;
 
   messages_ -> resize(cacheSlots);
