@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -41,16 +41,14 @@
 #define RENDEREXTENSION_ENABLE_SPLIT               0
 #define RENDEREXTENSION_ENABLE_COMPRESS            0
 
-#define RENDEREXTENSION_DATA_LIMIT                 5120
+#define RENDEREXTENSION_DATA_LIMIT                 6144
 #define RENDEREXTENSION_DATA_OFFSET                36
 
 #define RENDEREXTENSION_CACHE_SLOTS                6000
 #define RENDEREXTENSION_CACHE_THRESHOLD            20
 #define RENDEREXTENSION_CACHE_LOWER_THRESHOLD      10
 
-#define RENDEREXTENSION_CACHE_SLOTS_IF_PROTO_STEP_7                8000
-#define RENDEREXTENSION_CACHE_THRESHOLD_IF_PROTO_STEP_7            30
-#define RENDEREXTENSION_CACHE_LOWER_THRESHOLD_IF_PROTO_STEP_7      20
+#define RENDEREXTENSION_CACHE_SLOTS_IF_PROTO_STEP_7    8000
 
 //
 // Used to build the table of minor opcodes.
@@ -236,6 +234,8 @@ class RenderExtensionMessage : public Message
 
       unsigned char op;
 
+      unsigned char num_elm;
+
       unsigned int src_id;
       unsigned int dst_id;
 
@@ -244,6 +244,9 @@ class RenderExtensionMessage : public Message
 
       unsigned short src_x;
       unsigned short src_y;
+
+      unsigned short offset_x;
+      unsigned short offset_y;
     }
     composite_glyphs;
 
