@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -27,6 +27,37 @@
 #undef  TEST
 #undef  DEBUG
 
+unsigned int ServerReadBuffer::suggestedLength(unsigned int pendingLength)
+{
+  //
+  // Always read all the data that
+  // is available.
+  //
+
+  int readable = transport_ -> readable();
+
+  unsigned int readLength = (readable == -1 ? 0 : (unsigned int) readable);
+
+  if (readLength < pendingLength)
+  {
+    readLength = pendingLength;
+  }
+
+  //
+  // Even if the readable data is not
+  // enough to make a complete message,
+  // resize the buffer to accomodate
+  // it all.
+  //
+
+  if (pendingLength < remaining_)
+  {
+    readLength = remaining_;
+  }
+
+  return readLength;
+}  
+
 int ServerReadBuffer::locateMessage(const unsigned char *start,
                                         const unsigned char *end,
                                             unsigned int &controlLength,
@@ -38,8 +69,7 @@ int ServerReadBuffer::locateMessage(const unsigned char *start,
   #ifdef TEST
   *logofs << "ServerReadBuffer: Locating message for FD#"
           << transport_ -> fd() << " with " << size
-          << " bytes and remaining " << remaining_
-          << ".\n" << logofs_flush;
+          << " bytes.\n" << logofs_flush;
   #endif
 
   if (firstMessage_)
