@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -54,6 +54,11 @@ SetUnpackColormapStore::SetUnpackColormapStore(StaticCompressor *compressor)
   cacheThreshold      = SETUNPACKCOLORMAP_CACHE_THRESHOLD;
   cacheLowerThreshold = SETUNPACKCOLORMAP_CACHE_LOWER_THRESHOLD;
 
+  if (control -> isProtoStep8() == 1)
+  {
+    enableSplit = SETUNPACKCOLORMAP_ENABLE_SPLIT_IF_PROTO_STEP_8;
+  }
+
   messages_ -> resize(cacheSlots);
 
   for (T_messages::iterator i = messages_ -> begin();
@@ -176,7 +181,7 @@ int SetUnpackColormapStore::parseIdentity(Message *message, const unsigned char
   *logofs << name() << ": Parsed identity for message at " << message << ".\n" << logofs_flush;
   #endif
 
-  return true;
+  return 1;
 }
 
 int SetUnpackColormapStore::unparseIdentity(const Message *message, unsigned char *buffer,
@@ -194,7 +199,7 @@ int SetUnpackColormapStore::unparseIdentity(const Message *message, unsigned cha
   *logofs << name() << ": Unparsed identity for message at " << message << ".\n" << logofs_flush;
   #endif
 
-  return true;
+  return 1;
 }
 
 void SetUnpackColormapStore::dumpIdentity(const Message *message) const
