@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -536,7 +536,7 @@ int SetCloseOnExec(int fd)
 
 int GetBytesReadable(int fd)
 {
-  int readable = 0;
+  long readable = 0;
 
   //
   // It may fail, for example at session
@@ -555,12 +555,12 @@ int GetBytesReadable(int fd)
   }
 
   #ifdef TEST
-  *logofs << "Socket: Returning " << readable
-          << " bytes readable on FD#" << fd
-          << ".\n" << logofs_flush;
+  *logofs << "Socket: Returning " << (int) readable
+          << " bytes readable on FD#" << fd << ".\n"
+           << logofs_flush;
   #endif
 
-  return readable;
+  return (int) readable;
 }
 
 int GetBytesWritable(int fd)
