@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -60,9 +60,23 @@ int GetBytesQueued(int fd);
 // to the interface.
 //
 
+#include "Misc.h"
+
 inline int GetBytesReadable(int fd, int *readable)
 {
-  return ioctl(fd, FIONREAD, &readable);
+  long t;
+
+  int result = ioctl(fd, FIONREAD, &t);
+
+  #ifdef DEBUG
+  *logofs << "Socket: Bytes readable from FD#"
+          << fd << " are " << t << " with result "
+          << result << ".\n" << logofs_flush;
+  #endif
+
+  *readable = (int) t;
+
+  return result;
 }
 
 //
