@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -39,11 +39,9 @@
 #undef  DUMP
 
 //
-// Define this to lock and unlock the
-// memory-to-memory transport buffers
-// before they are accessed. The code
-// is outdated and doesn't work with
-// the current pthread library.
+// Used to lock and unlock the transport
+// buffers before they are accessed by
+// different threads.
 //
 
 #undef  THREADS
@@ -110,7 +108,6 @@ Transport::Transport(int fd) : fd_(fd)
   SetNonBlocking(fd_, 1);
 
   blocked_ = 0;
-  drained_ = 0;
   finish_  = 0;
 
   #ifdef REFERENCES
@@ -235,9 +232,18 @@ int Transport::write(T_write type, const unsigned char *data, const unsigned int
   // If an immediate write was requested then
   // flush the enqueued data first.
   //
+  // Alternatively may try to write only if
+  // the socket is not blocked.
+  //
+  // if (w_buffer_.length_ > 0 && blocked_ == 0 &&
+  //         type == write_immediate)
+  // {
+  //   ...
+  // }
+  //
+
+  if (w_buffer_.length_ > 0 && type == write_immediate)
 
-  if (w_buffer_.length_ > 0 && blocked_ == 0 &&
-          type == write_immediate)
   {
     #ifdef TEST
     *logofs << "Transport: Writing " << w_buffer_.length_
@@ -267,8 +273,7 @@ int Transport::write(T_write type, const unsigned char *data, const unsigned int
     // Limit the amount of data sent.
     //
 
-    unsigned int toWrite = ((int) size > control -> TransportWriteLimit ?
-                                 control -> TransportWriteLimit : size);
+    unsigned int toWrite = size;
 
     #ifdef DUMP
 
@@ -297,8 +302,6 @@ int Transport::write(T_write type, const unsigned char *data, const unsigned int
 
       diffTs = diffTimestamp(writeTs, getNewTimestamp());
 
-      control -> addWriteTime(diffTs);
-
       statistics -> addWriteTime(diffTs);
 
       if (result <= 0)
@@ -328,7 +331,7 @@ int Transport::write(T_write type, const unsigned char *data, const unsigned int
         else
         {
           #ifdef TEST
-          *logofs << "Transport: Write on " << "FD#" 
+          *logofs << "Transport: Write to " << "FD#" 
                   << fd_ << " failed.\n" << logofs_flush;
           #endif
 
@@ -440,8 +443,7 @@ int Transport::flush()
 
   int written = 0;
 
-  int toWrite = (w_buffer_.length_ > control -> TransportWriteLimit ?
-                      control -> TransportWriteLimit : w_buffer_.length_);
+  int toWrite = w_buffer_.length_;
 
   //
   // We will do our best to write any available
@@ -470,8 +472,6 @@ int Transport::flush()
 
     diffTs = diffTimestamp(writeTs, getNewTimestamp());
 
-    control -> addWriteTime(diffTs);
-
     statistics -> addWriteTime(diffTs);
 
     if (result <= 0)
@@ -501,7 +501,7 @@ int Transport::flush()
       else
       {
         #ifdef TEST
-        *logofs << "Transport: Write on " << "FD#" 
+        *logofs << "Transport: Write to " << "FD#" 
                 << fd_ << " failed.\n" << logofs_flush;
         #endif
 
@@ -533,7 +533,7 @@ int Transport::flush()
     #endif
 
     //
-    // Update buffer status.
+    // Update the buffer status.
     //
 
     w_buffer_.length_ -= written;
@@ -588,19 +588,18 @@ int Transport::drain(int limit, int timeout)
 {
   if (w_buffer_.length_ <= limit)
   {
-    return 0;
+    return 1;
   }
 
-  drained_ = 1;
-
   //
-  // Try to write all the data accumulated.
+  // Write the data accumulated in the write
+  // buffer until it is below the limit or
+  // the timeout is elapsed.
   //
 
   int toWrite = w_buffer_.length_;
 
-  int written   = 0;
-  int available = 0;
+  int written = 0;
 
   #ifdef TEST
   *logofs << "Transport: Draining " << toWrite - limit
@@ -625,123 +624,41 @@ int Transport::drain(int limit, int timeout)
   FD_ZERO(&readSet);
 
   int result;
+  int ready;
 
   while (w_buffer_.length_ - written > limit)
   {
-    writeTs = nowTs;
+    nowTs = getNewTimestamp();
 
-    result = ::write(fd_, w_buffer_.data_.begin() + w_buffer_.start_ +
-                         written, toWrite - written);
+    //
+    // Wait for descriptor to become
+    // readable or writable.
+    //
+
+    FD_SET(fd_, &writeSet);
+    FD_SET(fd_, &readSet);
+
+    setTimestamp(selectTs, timeout / 2);
+
+    idleTs = nowTs;
+
+    result = select(fd_ + 1, &readSet, &writeSet, NULL, &selectTs);
 
     nowTs = getNewTimestamp();
 
-    diffTs = diffTimestamp(writeTs, nowTs);
+    diffTs = diffTimestamp(idleTs, nowTs);
 
-    control -> addWriteTime(diffTs);
+    statistics -> addIdleTime(diffTs);
 
-    statistics -> addWriteTime(diffTs);
+    statistics -> subReadTime(diffTs);
 
-    if (result <= 0)
+    if (result < 0)
     {
-      if (EGET() == EAGAIN)
+      if (EGET() == EINTR)
       {
         #ifdef TEST
-        *logofs << "Transport: Write of " << toWrite - written
-                << " bytes on FD#" << fd_ << " would block.\n"
-                << logofs_flush;
-        #endif
-
-        //
-        // Check if the result of the last select
-        // told us that there are bytes readable.
-        //
-
-        if (available == 1)
-        {
-          #ifdef WARNING
-          *logofs << "Transport: WARNING! Not draining further "
-                  << "due to data readable on FD#" << fd_
-                  << ".\n" << logofs_flush;
-          #endif
-
-          break;
-        }
-
-        //
-        // Wait for descriptor to become writable.
-        //
-
-        FD_SET(fd_, &writeSet);
-        FD_SET(fd_, &readSet);
-
-        setTimestamp(selectTs, timeout / 2);
-
-        //
-        // Save a system call using the timestamp
-        // we got at the end of write.
-        //
-
-        idleTs = nowTs;
-
-        result = select(fd_ + 1, &readSet, &writeSet, NULL, &selectTs);
-
-        nowTs = getNewTimestamp();
-
-        diffTs = diffTimestamp(idleTs, nowTs);
-
-        control -> addIdleTime(diffTs);
-
-        control -> subReadTime(diffTs);
-
-        statistics -> addIdleTime(diffTs);
-
-        statistics -> subReadTime(diffTs);
-
-        diffTs = diffTimestamp(startTs, nowTs);
-
-        if (result > 0)
-        {
-          if (FD_ISSET(fd_, &readSet))
-          {
-            #ifdef TEST
-            *logofs << "Transport: The socket for FD#" << fd_
-                    << " became readable.\n" << logofs_flush;
-            #endif
-
-            available = 1;
-
-            if (result == 1)
-            {
-              #ifdef WARNING
-              *logofs << "Transport: WARNING! Not draining further "
-                      << "due to data readable on FD#" << fd_
-                      << ".\n" << logofs_flush;
-              #endif
-
-              break;
-            }
-          }
-        }
-        else if (result <= 0)
-        {
-          if (diffTs >= timeout)
-          {
-            #ifdef WARNING
-            *logofs << "Transport: WARNING! Not draining further "
-                    << "due to the timeout on FD#" << fd_
-                    << ".\n" << logofs_flush;
-            #endif
-
-            break;
-          }
-        }
-      }
-      else if (EGET() == EINTR)
-      {
-        #ifdef TEST
-        *logofs << "Transport: Write of " << toWrite - written
-                << " bytes on FD#" << fd_ << " was interrupted.\n"
-                << logofs_flush;
+        *logofs << "Transport: Select on FD#" << fd_
+                << " was interrupted.\n" << logofs_flush;
         #endif
 
         continue;
@@ -749,8 +666,8 @@ int Transport::drain(int limit, int timeout)
       else
       {
         #ifdef TEST
-        *logofs << "Transport: Write on " << "FD#" 
-                << fd_ << " failed.\n" << logofs_flush;
+        *logofs << "Transport: Select on FD#" << fd_
+                << " failed.\n" << logofs_flush;
         #endif
 
         finish();
@@ -758,22 +675,89 @@ int Transport::drain(int limit, int timeout)
         return -1;
       }
     }
+    else if (result > 0)
+    {
+      ready = result;
+
+      if (FD_ISSET(fd_, &writeSet))
+      {
+        writeTs = getNewTimestamp();
+
+        result = ::write(fd_, w_buffer_.data_.begin() + w_buffer_.start_ +
+                             written, toWrite - written);
+
+        nowTs = getNewTimestamp();
+
+        diffTs = diffTimestamp(writeTs, nowTs);
+
+        statistics -> addWriteTime(diffTs);
+
+        if (result > 0)
+        {
+          #ifdef TEST
+          *logofs << "Transport: Forced flush of " << result
+                  << " bytes on " << "FD#" << fd_ << ".\n"
+                  << logofs_flush;
+          #endif
+
+          written += result;
+        }
+        else if (result < 0 && EGET() == EINTR)
+        {
+          #ifdef TEST
+          *logofs << "Transport: Write to FD#" << fd_
+                  << " was interrupted.\n" << logofs_flush;
+          #endif
+
+          continue;
+        }
+        else
+        {
+          #ifdef TEST
+          *logofs << "Transport: Write to FD#" << fd_
+                  << " failed.\n" << logofs_flush;
+          #endif
+
+          finish();
+
+          return -1;
+        }
+
+        ready--;
+      }
+
+      if (ready > 0)
+      {
+        if (FD_ISSET(fd_, &readSet))
+        {
+          #ifdef TEST
+          *logofs << "Transport: Not draining further "
+                  << "due to data readable on FD#" << fd_
+                  << ".\n" << logofs_flush;
+          #endif
+
+          break;
+        }
+      }
+    }
+    #ifdef TEST
     else
     {
-      #ifdef TEST
-      *logofs << "Transport: Forced flush of " << result
-              << " bytes on " << "FD#" << fd_ << ".\n"
+      *logofs << "Transport: Timeout encountered "
+              << "waiting for FD#" << fd_ << ".\n"
               << logofs_flush;
-      #endif
-
-      written += result;
     }
+    #endif
 
-    if (available == 1)
+    nowTs = getNewTimestamp();
+
+    diffTs = diffTimestamp(startTs, nowTs);
+
+    if (diffTs >= timeout)
     {
-      #ifdef WARNING
-      *logofs << "Transport: WARNING! Not draining further "
-              << "due to data readable on FD#" << fd_
+      #ifdef TEST
+      *logofs << "Transport: Not draining further "
+              << "due to the timeout on FD#" << fd_
               << ".\n" << logofs_flush;
       #endif
 
@@ -793,7 +777,7 @@ int Transport::drain(int limit, int timeout)
     #endif
 
     //
-    // Update buffer status.
+    // Update the buffer status.
     //
 
     w_buffer_.length_ -= written;
@@ -907,10 +891,6 @@ int Transport::wait(int timeout) const
 
     diffTs = diffTimestamp(idleTs, nowTs);
 
-    control -> addIdleTime(diffTs);
-
-    control -> subReadTime(diffTs);
-
     statistics -> addIdleTime(diffTs);
 
     statistics -> subReadTime(diffTs);
@@ -967,13 +947,12 @@ void Transport::setSize(unsigned int initialSize, unsigned int thresholdSize,
   #endif
 }
 
-int Transport::fullReset()
+void Transport::fullReset()
 {
   blocked_ = 0;
-  drained_ = 0;
   finish_  = 0;
 
-  return fullReset(w_buffer_);
+  fullReset(w_buffer_);
 }
 
 int Transport::resize(T_buffer &buffer, const int &size)
@@ -982,20 +961,23 @@ int Transport::resize(T_buffer &buffer, const int &size)
           (buffer.start_ + buffer.length_ + size) >
                (int) buffer.data_.size())
   {
-    //
-    // There is enough space in buffer but we need
-    // to move existing data at the beginning.
-    //
+    if (buffer.length_ > 0)
+    {
+      //
+      // There is enough space in buffer but we need
+      // to move existing data at the beginning.
+      //
 
-    #ifdef TEST
-    *logofs << "Transport: Moving " << buffer.length_
-            << " bytes of data for " << "FD#" << fd_
-            << " to make room in the buffer.\n"
-            << logofs_flush;
-    #endif
+      #ifdef TEST
+      *logofs << "Transport: Moving " << buffer.length_
+              << " bytes of data for " << "FD#" << fd_
+              << " to make room in the buffer.\n"
+              << logofs_flush;
+      #endif
 
-    memmove(buffer.data_.begin(), buffer.data_.begin() +
-                buffer.start_, buffer.length_);
+      memmove(buffer.data_.begin(), buffer.data_.begin() +
+                  buffer.start_, buffer.length_);
+    }
 
     buffer.start_ = 0;
 
@@ -1010,10 +992,10 @@ int Transport::resize(T_buffer &buffer, const int &size)
   {
     //
     // Not enough space, so increase
-    // size of the buffer.
+    // the size of the buffer.
     //
 
-    if (buffer.start_ != 0)
+    if (buffer.start_ != 0 && buffer.length_ > 0)
     {
       #ifdef TEST
       *logofs << "Transport: Moving " << buffer.length_
@@ -1034,7 +1016,7 @@ int Transport::resize(T_buffer &buffer, const int &size)
     {
       newSize <<= 1;
 
-      if (newSize > maximumSize_)
+      if (newSize >= maximumSize_)
       {
         newSize = buffer.length_ + size + initialSize_;
       }
@@ -1069,7 +1051,7 @@ int Transport::resize(T_buffer &buffer, const int &size)
   return (buffer.length_ + size);
 }
 
-int Transport::fullReset(T_buffer &buffer)
+void Transport::fullReset(T_buffer &buffer)
 {
   //
   // Force deallocation and allocation
@@ -1086,24 +1068,20 @@ int Transport::fullReset(T_buffer &buffer)
   buffer.start_  = 0;
   buffer.length_ = 0;
 
-  if (buffer.data_.size() == (unsigned int) initialSize_ &&
-          buffer.data_.capacity() == (unsigned int) initialSize_)
+  if (buffer.data_.size() > (unsigned int) initialSize_ &&
+          buffer.data_.capacity() > (unsigned int) initialSize_)
   {
-    return 0;
+    buffer.data_.clear();
+
+    buffer.data_.resize(initialSize_);
+
+    #ifdef TEST
+    *logofs << "Transport: Data buffer for " << "FD#"
+            << fd_ << " shrunk to size " << buffer.data_.size()
+            << " and capacity " << buffer.data_.capacity()
+            << ".\n" << logofs_flush;
+    #endif
   }
-
-  buffer.data_.clear();
-
-  buffer.data_.resize(initialSize_);
-
-  #ifdef TEST
-  *logofs << "Transport: Data buffer for " << "FD#"
-          << fd_ << " shrunk to size " << buffer.data_.size()
-          << " and capacity " << buffer.data_.capacity()
-          << ".\n" << logofs_flush;
-  #endif
-
-  return 1;
 }
 
 ProxyTransport::ProxyTransport(int fd) : Transport(fd)
@@ -1124,6 +1102,12 @@ ProxyTransport::ProxyTransport(int fd) : Transport(fd)
 
   r_buffer_.data_.resize(initialSize_);
 
+  //
+  // For now we own the buffer.
+  //
+
+  owner_ = 1;
+
   //
   // Set up ZLIB compression.
   //
@@ -1216,8 +1200,9 @@ ProxyTransport::~ProxyTransport()
 int ProxyTransport::read(unsigned char *data, unsigned int size)
 {
   //
-  // If remote peer is not compressing the stream
-  // then just return any byte read from socket.
+  // If the remote peer is not compressing
+  // the stream then just return any byte
+  // read from the socket.
   //
 
   if (control -> RemoteStreamCompression == 0)
@@ -1229,8 +1214,6 @@ int ProxyTransport::read(unsigned char *data, unsigned int size)
       return result;
     }
 
-    control -> addBytesIn(result);
-
     statistics -> addBytesIn(result);
 
     return result;
@@ -1242,13 +1225,33 @@ int ProxyTransport::read(unsigned char *data, unsigned int size)
 
   if (r_buffer_.length_ > 0)
   {
+    //
+    // If the size of the buffer doesn't
+    // match the amount of data pending,
+    // force the caller to retry.
+    //
+
+    if ((int) size < r_buffer_.length_)
+    {
+      #ifdef TEST
+      *logofs << "ProxyTransport: WARNING! Forcing a retry with "
+              << r_buffer_.length_ << " bytes pending and "
+              << size << " in the buffer.\n"
+              << logofs_flush;
+      #endif
+
+      ESET(EAGAIN);
+
+      return -1;
+    }
+
     int copied = (r_buffer_.length_ > ((int) size) ?
                       ((int) size) : r_buffer_.length_);
 
     memcpy(data, r_buffer_.data_.begin() + r_buffer_.start_, copied);
 
     //
-    // Update buffer status.
+    // Update the buffer status.
     //
 
     #ifdef DEBUG
@@ -1288,16 +1291,15 @@ int ProxyTransport::read(unsigned char *data, unsigned int size)
     return result;
   }
 
-  control -> addBytesIn(result);
-
   statistics -> addBytesIn(result);
 
   //
-  // Uncompress data into the read buffer.
+  // Decompress the data into the read
+  // buffer.
   //
 
   #ifdef DEBUG
-  *logofs << "ProxyTransport: Going to uncompress data for " 
+  *logofs << "ProxyTransport: Going to decompress data for " 
           << "proxy FD#" << fd_ << ".\n" << logofs_flush;
   #endif
 
@@ -1324,11 +1326,12 @@ int ProxyTransport::read(unsigned char *data, unsigned int size)
   r_stream_.avail_in = result;
 
   //
-  // Initial buffer will be twice the
-  // amount of data read from socket.
+  // Let ZLIB use all the space already
+  // available in the buffer.
   //
 
-  int newAvailOut = (result < 1024 ? 2048 : result * 2);
+  unsigned int newAvailOut = r_buffer_.data_.size() - r_buffer_.start_ -
+                                 r_buffer_.length_;
 
   #ifdef TEST
   *logofs << "ProxyTransport: Initial decompress buffer is "
@@ -1338,7 +1341,7 @@ int ProxyTransport::read(unsigned char *data, unsigned int size)
   for (;;)
   {
     #ifdef INSPECT
-    *logofs << "\nProxyTransport: Running uncompress loop.\n"
+    *logofs << "\nProxyTransport: Running the decompress loop.\n"
             << logofs_flush;
     #endif
 
@@ -1493,9 +1496,18 @@ int ProxyTransport::read(unsigned char *data, unsigned int size)
       return -1;
     }
 
+    //
+    // Add more bytes to the buffer.
+    //
+
+    if (newAvailOut < thresholdSize_)
+    {
+      newAvailOut = thresholdSize_;
+    }
+
     #ifdef TEST
     *logofs << "ProxyTransport: Need to add " << newAvailOut
-            << " bytes to decompress buffer.\n"
+            << " bytes to the decompress buffer in read.\n"
             << logofs_flush;
     #endif
   }
@@ -1512,7 +1524,27 @@ int ProxyTransport::read(unsigned char *data, unsigned int size)
   statistics -> addDecompressedBytes(diffTotalIn, diffTotalOut);
 
   //
-  // Copy the uncompressed data to the provided buffer.
+  // Check if the size of the buffer
+  // matches the produced data.
+  //
+
+  if ((int) size < r_buffer_.length_)
+  {
+    #ifdef TEST
+    *logofs << "ProxyTransport: WARNING! Forcing a retry with "
+            << r_buffer_.length_ << " bytes pending and "
+            << size << " in the buffer.\n"
+            << logofs_flush;
+    #endif
+
+    ESET(EAGAIN);
+
+    return -1;
+  }
+
+  //
+  // Copy the decompressed data to the
+  // provided buffer.
   //
 
   int copied = (r_buffer_.length_ > ((int) size) ?
@@ -1527,7 +1559,7 @@ int ProxyTransport::read(unsigned char *data, unsigned int size)
   memcpy(data, r_buffer_.data_.begin() + r_buffer_.start_, copied);
 
   //
-  // Update buffer status.
+  // Update the buffer status.
   //
 
   r_buffer_.length_ -= copied;
@@ -1581,11 +1613,11 @@ int ProxyTransport::write(T_write type, const unsigned char *data, const unsigne
       return result;
     }
 
-    control -> addBytesOut(result);
-
     statistics -> addBytesOut(result);
 
-    control -> updateBitrate(result);
+    statistics -> updateBitrate(result);
+
+    FlushCallback(result);
 
     return result;
   }
@@ -1623,11 +1655,12 @@ int ProxyTransport::write(T_write type, const unsigned char *data, const unsigne
   w_stream_.avail_in = size;
 
   //
-  // Initial buffer will be the amount of data to
-  // compress plus the data to flush plus overhead.
+  // Let ZLIB use all the space already
+  // available in the buffer.
   //
 
-  int newAvailOut = (size + flush_) + ((size + flush_) / 100) + 12;
+  unsigned int newAvailOut = w_buffer_.data_.size() - w_buffer_.start_ -
+                                 w_buffer_.length_;
 
   #ifdef TEST
   *logofs << "ProxyTransport: Initial compress buffer is "
@@ -1637,7 +1670,7 @@ int ProxyTransport::write(T_write type, const unsigned char *data, const unsigne
   for (;;)
   {
     #ifdef INSPECT
-    *logofs << "\nProxyTransport: Running compress loop.\n"
+    *logofs << "\nProxyTransport: Running the compress loop.\n"
             << logofs_flush;
     #endif
 
@@ -1796,9 +1829,18 @@ int ProxyTransport::write(T_write type, const unsigned char *data, const unsigne
       return -1;
     }
 
+    //
+    // Add more bytes to the buffer.
+    //
+
+    if (newAvailOut < thresholdSize_)
+    {
+      newAvailOut = thresholdSize_;
+    }
+
     #ifdef TEST
     *logofs << "ProxyTransport: Need to add " << newAvailOut
-            << " bytes to compress buffer.\n"
+            << " bytes to the compress buffer in write.\n"
             << logofs_flush;
     #endif
   }
@@ -1850,7 +1892,18 @@ int ProxyTransport::write(T_write type, const unsigned char *data, const unsigne
             << ".\n" << logofs_flush;
     #endif
 
-    if (w_buffer_.length_ > 0 && blocked_ == 0)
+    //
+    // Alternatively may try to write only if
+    // the socket is not blocked.
+    //
+    // if (w_buffer_.length_ > 0 && blocked_ == 0)
+    // {
+    //   ...
+    // }
+    //
+
+    if (w_buffer_.length_ > 0)
+
     {
       #ifdef TEST
       *logofs << "ProxyTransport: Writing " << w_buffer_.length_
@@ -1884,13 +1937,13 @@ int ProxyTransport::write(T_write type, const unsigned char *data, const unsigne
   // bitrate earlier.
   //
 
-  control -> addBytesOut(diffTotalOut);
-
   statistics -> addCompressedBytes(diffTotalIn, diffTotalOut);
 
   statistics -> addBytesOut(diffTotalOut);
 
-  control -> updateBitrate(diffTotalOut);
+  statistics -> updateBitrate(diffTotalOut);
+
+  FlushCallback(diffTotalOut);
 
   #ifdef TEST
   *logofs << "ProxyTransport: Write buffer for proxy FD#" << fd_
@@ -1969,11 +2022,12 @@ int ProxyTransport::flush()
   w_stream_.avail_in = 0;
 
   //
-  // Initial buffer will be the amount
-  // of data to flush plus overhead.
+  // Let ZLIB use all the space already
+  // available in the buffer.
   //
 
-  int newAvailOut = flush_ + (flush_ / 100) + 12;
+  unsigned int newAvailOut = w_buffer_.data_.size() - w_buffer_.start_ -
+                                 w_buffer_.length_;
 
   #ifdef DEBUG
   *logofs << "ProxyTransport: Initial flush buffer is "
@@ -1983,7 +2037,7 @@ int ProxyTransport::flush()
   for (;;)
   {
     #ifdef INSPECT
-    *logofs << "\nProxyTransport: Running flush loop.\n"
+    *logofs << "\nProxyTransport: Running the flush loop.\n"
             << logofs_flush;
     #endif
 
@@ -2141,9 +2195,18 @@ int ProxyTransport::flush()
       return -1;
     }
 
+    //
+    // Add more bytes to the buffer.
+    //
+
+    if (newAvailOut < thresholdSize_)
+    {
+      newAvailOut = thresholdSize_;
+    }
+
     #ifdef TEST
     *logofs << "ProxyTransport: Need to add " << newAvailOut
-            << " bytes to compress buffer in flush.\n"
+            << " bytes to the compress buffer in flush.\n"
             << logofs_flush;
     #endif
   }
@@ -2189,52 +2252,86 @@ int ProxyTransport::flush()
   }
 
   //
-  // Update all the ounters.
+  // Update all the counters.
   //
 
-  control -> addBytesOut(diffTotalOut);
-
   statistics -> addCompressedBytes(diffTotalIn, diffTotalOut);
 
   statistics -> addBytesOut(diffTotalOut);
 
-  control -> updateBitrate(diffTotalOut);
+  statistics -> updateBitrate(diffTotalOut);
+
+  FlushCallback(diffTotalOut);
 
   return result;
 }
 
-int ProxyTransport::fullReset()
+unsigned int ProxyTransport::getPending(unsigned char *&data)
+{
+  //
+  // Return a pointer to the data in the
+  // read buffer. It is up to the caller
+  // to ensure that the data is consumed
+  // before the read buffer is reused.
+  //
+
+  if (r_buffer_.length_ > 0)
+  {
+    unsigned int size = r_buffer_.length_;
+
+    data = r_buffer_.data_.begin() + r_buffer_.start_;
+
+    #ifdef DEBUG
+    *logofs << "ProxyTransport: Returning " << size
+            << " pending bytes from proxy FD#" << fd_
+            << ".\n" << logofs_flush;
+    #endif
+
+    r_buffer_.length_ = 0;
+    r_buffer_.start_  = 0;
+
+    //
+    // Prevent the deletion of the buffer.
+    //
+
+    owner_ = 0;
+
+    return size;
+  }
+
+  #ifdef TEST
+  *logofs << "ProxyTransport: WARNING! No pending data "
+          << "for proxy FD#" << fd_ << ".\n"
+          << logofs_flush;
+  #endif
+
+  data = NULL;
+
+  return 0;
+}
+
+void ProxyTransport::fullReset()
 {
   blocked_ = 0;
-  drained_ = 0;
   finish_  = 0;
   flush_   = 0;
 
-  int result = 0;
-
-  if (control -> RemoteStreamCompression &&
-          inflateReset(&r_stream_) == Z_OK)
+  if (control -> RemoteStreamCompression)
   {
-    result++;
+    inflateReset(&r_stream_);
   }
 
-  if (control -> LocalStreamCompression &&
-          deflateReset(&w_stream_) == Z_OK)
+  if (control -> LocalStreamCompression)
   {
-    result++;
+    deflateReset(&w_stream_);
   }
 
-  if (Transport::fullReset(r_buffer_) >= 0)
+  if (owner_ == 1)
   {
-    result++;
+    Transport::fullReset(r_buffer_);
   }
 
-  if (Transport::fullReset(w_buffer_) >= 0)
-  {
-    result++;
-  }
-
-  return (result == 4);
+  Transport::fullReset(w_buffer_);
 }
 
 AgentTransport::AgentTransport(int fd) : Transport(fd)
@@ -2255,6 +2352,12 @@ AgentTransport::AgentTransport(int fd) : Transport(fd)
 
   r_buffer_.data_.resize(initialSize_);
 
+  //
+  // For now we own the buffer.
+  //
+
+  owner_ = 1;
+
   //
   // Set up the mutexes.
   //
@@ -2345,55 +2448,69 @@ int AgentTransport::read(unsigned char *data, unsigned int size)
           << logofs_flush;
   #endif
 
-  int copied = 0;
+  int copied = -1;
 
   if (r_buffer_.length_ > 0)
   {
-    copied = (r_buffer_.length_ > ((int) size) ?
-                  ((int) size) : r_buffer_.length_);
-
-    memcpy(data, r_buffer_.data_.begin() + r_buffer_.start_, copied);
-
-    //
-    // Update buffer status.
-    //
-
-    #ifdef TEST
-    *logofs << "AgentTransport: Child: Going to immediately return "
-            << copied << " bytes from FD#" << fd_ << ".\n"
-            << logofs_flush;
-    #endif
-
-    #ifdef DUMP
-
-    *logofs << "AgentTransport: Child: Dumping content of read data.\n"
-            << logofs_flush;
-
-    DumpData(data, copied);
-
-    #endif
-
-    r_buffer_.length_ -= copied;
-
-    if (r_buffer_.length_ == 0)
+    if ((int) size < r_buffer_.length_)
     {
-      r_buffer_.start_ = 0;
+      #ifdef TEST
+      *logofs << "AgentTransport: WARNING! Forcing a retry with "
+              << r_buffer_.length_ << " bytes pending and "
+              << size << " in the buffer.\n"
+              << logofs_flush;
+      #endif
+
+      ESET(EAGAIN);
     }
     else
     {
-      r_buffer_.start_ += copied;
+      copied = (r_buffer_.length_ > ((int) size) ?
+                    ((int) size) : r_buffer_.length_);
+
+      memcpy(data, r_buffer_.data_.begin() + r_buffer_.start_, copied);
+
+      //
+      // Update the buffer status.
+      //
 
       #ifdef TEST
-      *logofs << "AgentTransport: Child: There are still "
-              << r_buffer_.length_  << " bytes in read buffer for "
-              << "FD#" << fd_ << ".\n" << logofs_flush;
+      *logofs << "AgentTransport: Child: Going to immediately return "
+              << copied << " bytes from FD#" << fd_ << ".\n"
+              << logofs_flush;
       #endif
+
+      #ifdef DUMP
+
+      *logofs << "AgentTransport: Child: Dumping content of read data.\n"
+              << logofs_flush;
+
+      DumpData(data, copied);
+
+      #endif
+
+      r_buffer_.length_ -= copied;
+
+      if (r_buffer_.length_ == 0)
+      {
+        r_buffer_.start_ = 0;
+      }
+      else
+      {
+        r_buffer_.start_ += copied;
+
+        #ifdef TEST
+        *logofs << "AgentTransport: Child: There are still "
+                << r_buffer_.length_  << " bytes in read buffer for "
+                << "FD#" << fd_ << ".\n" << logofs_flush;
+        #endif
+      }
     }
   }
   else
   {
     #ifdef DEBUG
-    *logofs << "AgentTransport: Child: No data can be gotten "
+    *logofs << "AgentTransport: Child: No data can be got "
             << "from read buffer for FD#" << fd_ << ".\n"
             << logofs_flush;
     #endif
@@ -2407,14 +2524,6 @@ int AgentTransport::read(unsigned char *data, unsigned int size)
 
   #endif
 
-  //
-  // Update the timestamp because the
-  // agent may have run for a relevant
-  // amount of time.
-  //
-
-  getNewTimestamp();
-
   return copied;
 }
 
@@ -2444,15 +2553,13 @@ int AgentTransport::write(T_write type, const unsigned char *data, const unsigne
           << ".\n" << logofs_flush;
   #endif
 
-  int copied = 0;
+  int copied = -1;
 
   if (resize(w_buffer_, size) < 0)
   {
     finish();
 
     ESET(EPIPE);
-
-    copied = -1;
   }
   else
   {
@@ -2520,50 +2627,86 @@ int AgentTransport::flush()
 int AgentTransport::drain(int limit, int timeout)
 {
   //
-  // This function should be never called in
-  // the case of memory-to-memory transport.
-  // Data is enqueued for the agent to read
-  // but the agent could require multiple
-  // loops to read it all.
+  // We can't drain the channel in the case
+  // of the memory-to-memory transport. Data
+  // is enqueued for the agent to read but
+  // the agent could require multiple loops
+  // to read it all.
   //
 
-  #ifdef TEST
-  *logofs << "AgentTransport: Child: WARNING! Called drain() for "
+  //
+  // In case of memory-to-memory transport
+  // this function should never be called.
+  //
+
+  #ifdef PANIC
+  *logofs << "AgentTransport: Child: PANIC! Called drain() for "
           << "memory to memory transport on " << "FD#"
           << fd_ << ".\n" << logofs_flush;
   #endif
 
+  cerr << "Error" << ": Called drain() for "
+       << "memory to memory transport on " << "FD#"
+       << fd_ << ".\n";
+
+  HandleAbort();
+}
+
+unsigned int AgentTransport::getPending(unsigned char *&data)
+{
+  #ifdef THREADS
+
+  lockRead();
+
+  #endif
+
+  if (r_buffer_.length_ > 0)
+  {
+    unsigned int size = r_buffer_.length_;
+
+    data = r_buffer_.data_.begin() + r_buffer_.start_;
+
+    #ifdef DEBUG
+    *logofs << "AgentTransport: Child: Returning " << size
+            << " pending bytes from FD#" << fd_
+            << ".\n" << logofs_flush;
+    #endif
+
+    r_buffer_.length_ = 0;
+    r_buffer_.start_  = 0;
+
+    #ifdef THREADS
+
+    unlockRead();
+
+    #endif
+
+    //
+    // Prevent the deletion of the buffer.
+    //
+
+    owner_ = 0;
+
+    return size;
+  }
+
+  #ifdef TEST
+  *logofs << "AgentTransport: WARNING! No pending data "
+          << "for FD#" << fd_ << ".\n" << logofs_flush;
+  #endif
+
+  #ifdef THREADS
+
+  unlockRead();
+
+  #endif
+
+  data = NULL;
+
   return 0;
 }
 
-int AgentTransport::writable() const
-{
-  #if defined(PARENT) && (defined(TEST) || defined(INFO))
-  *logofs << "AgentTransport: Child: WARNING! Called for "
-          << "FD#" << fd_ << ".\n" << logofs_flush;
-  #endif
-
-  int writable = control -> TransportXBufferThreshold -
-                     w_buffer_.length_;
-
-  if (writable < 0)
-  {
-    writable = 0;
-  }
-
-  #if defined(PARENT) && (defined(TEST) || defined(INFO))
-  if (writable <= 0)
-  {
-    *logofs << "AgentTransport: Child: WARNING! No data is "
-            << "writable on write buffer for FD#" << fd_
-            << ".\n" << logofs_flush;
-  }
-  #endif
-
-  return writable;
-}
-
-int AgentTransport::fullReset()
+void AgentTransport::fullReset()
 {
   #ifdef THREADS
 
@@ -2578,22 +2721,14 @@ int AgentTransport::fullReset()
   #endif
 
   blocked_ = 0;
-  drained_ = 0;
   finish_  = 0;
 
-  int result = 0;
-
-  if (Transport::fullReset(r_buffer_) >= 0)
+  if (owner_ == 1)
   {
-    result++;
+    Transport::fullReset(r_buffer_);
   }
 
-  if (Transport::fullReset(w_buffer_) >= 0)
-  {
-    result++;
-  }
-
-  return (result == 2);
+  Transport::fullReset(w_buffer_);
 }
 
 int AgentTransport::enqueue(const char *data, const int size)
@@ -2618,34 +2753,11 @@ int AgentTransport::enqueue(const char *data, const int size)
   }
 
   //
-  // Don't allow the agent to write more data
-  // than the threshold.
+  // Always allow the agent to write
+  // all its data.
   //
 
-  int toPut = control -> TransportXBufferThreshold -
-                  r_buffer_.length_;
-
-  if (toPut <= 0)
-  {
-    #if defined(PARENT) && defined(TEST)
-    *logofs << "AgentTransport: Parent: WARNING! Read buffer for FD#"
-            << fd_ << " has already reached the limit of "
-            << control -> TransportXBufferThreshold
-            << " bytes.\n" << logofs_flush;
-    #endif
-
-    ESET(EAGAIN);
-
-    #ifdef THREADS
-
-    unlockRead();
-
-    #endif
-
-    return -1;
-  }
-
-  toPut = (toPut > size ? size : toPut);
+  int toPut = size;
 
   #if defined(PARENT) && defined(TEST)
   *logofs << "AgentTransport: Parent: Going to put " << toPut
@@ -2676,7 +2788,7 @@ int AgentTransport::enqueue(const char *data, const int size)
   *logofs << "AgentTransport: Parent: Dumping content of enqueued data.\n"
           << logofs_flush;
 
-  DumpData(data, toPut);
+  DumpData((const unsigned char *) data, toPut);
 
   #endif
 
@@ -2761,7 +2873,7 @@ int AgentTransport::dequeue(char *data, int size)
   *logofs << "AgentTransport: Parent: Dumping content of dequeued data.\n"
           << logofs_flush;
 
-  DumpData(data, toGet);
+  DumpData((const unsigned char *) data, toGet);
 
   #endif
 
@@ -2786,40 +2898,6 @@ int AgentTransport::dequeue(char *data, int size)
   return toGet;
 }
 
-int AgentTransport::queuable()
-{
-  #ifdef THREADS
-
-  lockRead();
-
-  #endif
-
-  int queuable = control -> TransportXBufferThreshold -
-                     r_buffer_.length_;
-
-  if (queuable < 0)
-  {
-    queuable = 0;
-  }
-
-  #if defined(PARENT) && defined(TEST)
-  if (queuable <= 0)
-  {
-    *logofs << "AgentTransport: Parent: No data is queuable "
-            << "on read buffer for FD#" << fd_ << ".\n"
-            << logofs_flush;
-  }
-  #endif
-
-  #ifdef THREADS
-
-  unlockRead();
-
-  #endif
-
-  return queuable;
-}
-
 int AgentTransport::dequeuable()
 {
   if (finish_ == 1)
