@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -74,6 +74,7 @@ typedef enum
   transport_proxy,
   transport_agent,
   transport_last_tag
+
 } T_transport_type;
 
 //
@@ -188,25 +189,34 @@ class Transport
     return 0;
   }
 
-  int drained() const
-  {
-    return drained_;
-  }
-
   virtual int wait(int timeout) const;
 
   void setSize(unsigned int initialSize,
                    unsigned int thresholdSize,
                        unsigned int maximumSize);
 
-  virtual int partialReset()
-  {
-    drained_ = 0;
+  //
+  // Return a pointer to the data
+  // in the read buffer.
+  //
 
-    return partialReset(w_buffer_);
+  virtual unsigned int getPending(unsigned char *&data)
+  {
+    data = NULL;
+
+    return 0;
   }
 
-  virtual int fullReset();
+  virtual void pendingReset()
+  {
+  }
+
+  virtual void partialReset()
+  {
+    partialReset(w_buffer_);
+  }
+
+  virtual void fullReset();
 
   int blocked() const
   {
@@ -222,19 +232,17 @@ class Transport
 
   int resize(T_buffer &buffer, const int &size);
 
-  int partialReset(T_buffer &buffer)
+  void partialReset(T_buffer &buffer)
   {
     if (buffer.length_ == 0 &&
             (buffer.data_.size() > initialSize_ ||
                  buffer.data_.capacity() > initialSize_))
     {
-      return fullReset(buffer);
+      fullReset(buffer);
     }
-
-    return 0;
   }
 
-  int fullReset(T_buffer &buffer);
+  void fullReset(T_buffer &buffer);
 
   //
   // Data members.
@@ -243,7 +251,6 @@ class Transport
   int fd_;
 
   int blocked_;
-  int drained_;
   int finish_;
 
   T_buffer w_buffer_;
@@ -333,15 +340,24 @@ class ProxyTransport : public Transport
   //                      unsigned int maximumSize);
   //
 
-  virtual int partialReset()
-  {
-    drained_ = 0;
+  virtual unsigned int getPending(unsigned char *&data);
 
-    return (Transport::partialReset(r_buffer_) &&
-                Transport::partialReset(w_buffer_));
+  virtual void pendingReset()
+  {
+    owner_ = 1;
   }
 
-  virtual int fullReset();
+  virtual void partialReset()
+  {
+    if (owner_ == 1)
+    {
+      Transport::partialReset(r_buffer_);
+    }
+
+    Transport::partialReset(w_buffer_);
+  }
+
+  virtual void fullReset();
 
   //
   // Same as in the base class.
@@ -352,6 +368,7 @@ class ProxyTransport : public Transport
   protected:
 
   int flush_;
+  int owner_;
 
   T_buffer r_buffer_;
 
@@ -419,7 +436,10 @@ class AgentTransport : public Transport
     return r_buffer_.length_;
   }
 
-  virtual int writable() const;
+  virtual int writable() const
+  {
+    return control -> TransportMaximumBufferSize;
+  }
 
   virtual int queued() const
   {
@@ -455,15 +475,24 @@ class AgentTransport : public Transport
   //                      unsigned int maximumSize);
   //
 
-  virtual int partialReset()
-  {
-    drained_ = 0;
+  virtual unsigned int getPending(unsigned char *&data);
 
-    return (Transport::partialReset(r_buffer_) &&
-                Transport::partialReset(w_buffer_));
+  virtual void pendingReset()
+  {
+    owner_ = 1;
   }
 
-  virtual int fullReset();
+  virtual void partialReset()
+  {
+    if (owner_ == 1)
+    {
+      Transport::partialReset(r_buffer_);
+    }
+
+    Transport::partialReset(w_buffer_);
+  }
+
+  virtual void fullReset();
 
   //
   // Same as in the base class.
@@ -480,7 +509,15 @@ class AgentTransport : public Transport
 
   int dequeue(char *data, int size);
 
-  int queuable();
+  int queuable()
+  {
+    //
+    // Always allow the agent to enqueue
+    // more data.
+    //
+
+    return control -> TransportMaximumBufferSize;
+  }
 
   int dequeuable();
 
@@ -505,6 +542,8 @@ class AgentTransport : public Transport
   // Data members.
   //
 
+  int owner_;
+
   T_buffer r_buffer_;
 
   //
