@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -32,7 +32,7 @@ z_stream unpackStream;
 
 static int unpackInitialized;
 
-int UnpackInit()
+void UnpackInit()
 {
   if (unpackInitialized == 0)
   {
@@ -62,8 +62,16 @@ int UnpackInit()
       unpackInitialized = 1;
     }
   }
+}
 
-  return unpackInitialized;
+void UnpackDestroy()
+{
+  if (unpackInitialized == 1)
+  {
+    inflateEnd(&unpackStream);
+
+    unpackInitialized = 0;
+  }
 }
 
 //
@@ -1056,8 +1064,8 @@ int Unpack15(T_geometry *geometry, int src_depth, int src_width, int src_height,
   return 1;
 }
 
-int Unpack16To16(const unsigned char *data,
-                    unsigned char *out, unsigned char *end)
+int Unpack16To16(const unsigned char *data, unsigned char *out,
+                    unsigned char *end, int imageByteOrder)
 {
   #ifdef TEST
   *logofs << "Unpack16To16: Unpacking " << end - out
@@ -1070,7 +1078,8 @@ int Unpack16To16(const unsigned char *data,
   return 1;
 }
 
-int Unpack16To24(const unsigned char *data, unsigned char *out, unsigned char *end)
+int Unpack16To24(const unsigned char *data, unsigned char *out, 
+                    unsigned char *end, int imageByteOrder)
 
 {
   #ifdef TEST
@@ -1114,7 +1123,8 @@ int Unpack16To24(const unsigned char *data, unsigned char *out, unsigned char *e
 }
 
 
-int Unpack16To32(const unsigned char *data, unsigned char *out, unsigned char *end)
+int Unpack16To32(const unsigned char *data, unsigned char *out, 
+                    unsigned char *end, int imageByteOrder)
 {
   #ifdef TEST
   *logofs << "Unpack16To32: Unpacking " << end - out
@@ -1126,24 +1136,31 @@ int Unpack16To32(const unsigned char *data, unsigned char *out, unsigned char *e
   unsigned int *out32 = (unsigned int *) out;
   unsigned int *end32 = (unsigned int *) end;
 
+  unsigned short pixel16;
+  unsigned int pixel32;
+
   while (out32 < end32)
   {
-    if (*data16 == 0x0)
+
+    pixel16 = GetUINT((unsigned char *)data16, 0);
+
+    if (pixel16 == 0x0)
     {
-      *out32 = 0x0;
+      PutULONG(0x0, (unsigned char *) out32, imageByteOrder); 
     }
-    else if (*data16 == 0xffff)
+    else if (pixel16 == 0xffff)
     {
-      *out32 = 0xffffff;
+      PutULONG(0xffffff, (unsigned char *) out32, imageByteOrder);
     }
     else
     {
-      
-      *out32 = ((((*data16 >> 8) & 0xf8) | ((*data16 >> 13) & 0x07)) << 16) | 
-               ((((*data16 >> 3) & 0xfc) | ((*data16 >> 9) & 0x03)) << 8) | 
-               (((*data16 << 3) & 0xf8) | ((*data16 >> 2) & 0x07));
-      
+      pixel32 = ((((pixel16 >> 8) & 0xf8) | ((pixel16 >> 13) & 0x07)) << 16) | 
+               ((((pixel16 >> 3) & 0xfc) | ((pixel16 >> 9) & 0x03)) << 8) | 
+               (((pixel16 << 3) & 0xf8) | ((pixel16 >> 2) & 0x07));
+ 
+      PutULONG(pixel32, (unsigned char *) out32, imageByteOrder); 
     }
+
     out32++;
     data16++;
   }
@@ -1154,6 +1171,8 @@ int Unpack16(T_geometry *geometry, int src_depth, int src_width, int src_height,
                  unsigned char *src_data, int src_size, int dst_depth, int dst_width,
                      int dst_height, unsigned char *dst_data, int dst_size)
 {
+  int imageByteOrder = geometry -> image_byte_order;
+
   if (src_depth != 16)
   {
     #ifdef PANIC
@@ -1164,7 +1183,8 @@ int Unpack16(T_geometry *geometry, int src_depth, int src_width, int src_height,
     return -1;
   }
 
-  int (*unpack)(const unsigned char *data, unsigned char *out, unsigned char *end);
+  int (*unpack)(const unsigned char *data, unsigned char *out, 
+                    unsigned char *end, int imageByteOrder);
 
   int dst_bpp = UnpackBitsPerPixel(geometry, dst_depth);
   
@@ -1204,7 +1224,7 @@ int Unpack16(T_geometry *geometry, int src_depth, int src_width, int src_height,
   {
     unsigned char *dst_end = dst_data + dst_size;
 
-    (*unpack)(src_data, dst_data, dst_end);
+    (*unpack)(src_data, dst_data, dst_end, imageByteOrder);
   }
   else if (src_width >= dst_width && src_height >= dst_height)
   {
@@ -1215,7 +1235,7 @@ int Unpack16(T_geometry *geometry, int src_depth, int src_width, int src_height,
       dst_data = dst_end;
       dst_end += RoundUp4(dst_width * dst_bpp / 8);
 
-      (*unpack)(src_data, dst_data, dst_end);
+      (*unpack)(src_data, dst_data, dst_end, imageByteOrder);
 
       src_data += src_width * 2;
     }
