@@ -1,15 +1,15 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
+/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -22,6 +22,9 @@
 
 #include "Z.h"
 
+#define LSBFirst  0
+#define MSBFirst  1
+
 #define SPLIT_PATTERN  0x88
 
 typedef ColorMask T_colormask;
@@ -38,10 +41,16 @@ typedef struct
   unsigned int depth16_bpp;
   unsigned int depth24_bpp;
   unsigned int depth32_bpp;
+
   unsigned int red_mask;
   unsigned int green_mask;
   unsigned int blue_mask;
 
+  unsigned int image_byte_order;
+  unsigned int bitmap_bit_order;
+  unsigned int scanline_unit;
+  unsigned int scanline_pad;
+
 } T_geometry;
 
 //
@@ -81,7 +90,13 @@ extern z_stream unpackStream;
 // decompression.
 //
 
-int UnpackInit();
+void UnpackInit();
+
+//
+// Free the ZLIB stream.
+//
+
+void UnpackDestroy();
 
 //
 // Get the destination bits per pixel
